@@ -30,7 +30,7 @@
 #include "edit.h"
 
 #ifndef DEFAULT_ALTMASK
-#ifdef __linux__			/* a.r. */
+#if defined(__linux__) || defined(__osf__)			/* a.r. */
 #define DEFAULT_ALTMASK Mod1Mask
 #else
 #define DEFAULT_ALTMASK Mod4Mask
@@ -43,20 +43,20 @@ WpeXStruct WpeXInfo;
 /* Standard colors (after initialization pointers may not be valid) */
 static char *WpeXColorNames[16] = {
  "Black",
- "Dark Slate Blue",
- "Forest Green",
- "Turquoise3",
  "Red3",
- "Violet Red",
+ "Forest Green",
  "Brown",
+ "Dark Slate Blue",
+ "Violet Red",
+ "Turquoise3",
  "Light Gray",
  "Dark Slate Grey",
- "Blue",
- "Green",
- "Turquoise1",
  "Red1",
- "Violet",
+ "Green",
  "Yellow",
+ "Blue",
+ "Violet",
+ "Turquoise1",
  "White"
 };
 
@@ -354,12 +354,12 @@ void WpeXGCSetup()
  WpeXInfo.gc = XCreateGC(WpeXInfo.display, WpeXInfo.window, 0, &values);
  XSetFont(WpeXInfo.display, WpeXInfo.gc, WpeXInfo.font->fid);
  XSetForeground(WpeXInfo.display, WpeXInfo.gc,
-                BlackPixel(WpeXInfo.display, WpeXInfo.screen));
+   BlackPixel(WpeXInfo.display, WpeXInfo.screen));
  XSetLineAttributes(WpeXInfo.display, WpeXInfo.gc, /*line width*/ 1,
-                    /*line style*/ LineSolid, /*cap style*/ CapRound,
-                    /*join style*/ JoinRound);
+   /*line style*/ LineSolid, /*cap style*/ CapRound,
+   /*join style*/ JoinRound);
  XSetDashes(WpeXInfo.display, WpeXInfo.gc, /*dash offset*/ 0, dash_list,
-            /*dash list length*/ 2);
+   /*dash list length*/ 2);
  return ;
 }
 
@@ -398,7 +398,7 @@ void WpeXInit(int *argc, char **argv)
  }
  class_hint.res_class = "Xwpe";
  XrmParseCommand(&xres, WpeXOptionTable, OPTION_TABLE_SIZE,
-                 class_hint.res_name, argc, argv);
+   class_hint.res_name, argc, argv);
  class_list[0] = XrmStringToQuark(class_hint.res_class);
  name_list[0] = XrmStringToQuark(class_hint.res_name);
  /* The second class quark is set to "display" since it doesn't matter */
@@ -415,7 +415,7 @@ void WpeXInit(int *argc, char **argv)
  if ((WpeXInfo.display = XOpenDisplay(display_name)) == NULL)
  {
   fprintf(stderr, "Xwpe: unable to open display \"%s\", exiting ...\n",
-          XDisplayName(display_name));
+    XDisplayName(display_name));
   exit(-1);
  }
  WpeXInfo.screen = DefaultScreen(WpeXInfo.display);
@@ -438,23 +438,25 @@ void WpeXInit(int *argc, char **argv)
  wm_hints.window_group = WpeXInfo.window;
  
  XmbSetWMProperties(WpeXInfo.display, WpeXInfo.window, window_name,
-                    class_hint.res_name, argv, *argc, &size_hints,
-                    &wm_hints, &class_hint);
+   class_hint.res_name, argv, *argc, &size_hints, &wm_hints, &class_hint);
  XSelectInput(WpeXInfo.display, WpeXInfo.window, ExposureMask |
-              KeyPressMask | ButtonPressMask | StructureNotifyMask);
+   KeyPressMask | ButtonPressMask | StructureNotifyMask);
 
  if(!XGetWMProtocols(WpeXInfo.display, WpeXInfo.window, &atom_list, &atom_num))
  {
   atom_num = 0;
  }
  new_atom_list = WpeMalloc((atom_num + 1) * sizeof(Atom));
- memcpy(new_atom_list, atom_list, atom_num * sizeof(Atom));
+ if (atom_list != NULL)
+ {
+  memcpy(new_atom_list, atom_list, atom_num * sizeof(Atom));
+ }
  if (atom_num) XFree(atom_list);
  new_atom_list[atom_num] = WpeXInfo.delete_atom =
-                     XInternAtom(WpeXInfo.display, "WM_DELETE_WINDOW", False);
+   XInternAtom(WpeXInfo.display, "WM_DELETE_WINDOW", False);
  WpeXInfo.protocol_atom = XInternAtom(WpeXInfo.display, "WM_PROTOCOLS", False);
  XSetWMProtocols(WpeXInfo.display, WpeXInfo.window, new_atom_list,
-                 atom_num + 1);
+   atom_num + 1);
  WpeFree(new_atom_list);
 
  WpeXInfo.selection_atom = XInternAtom(WpeXInfo.display, "PRIMARY", False);
