@@ -156,8 +156,8 @@ typedef struct STR {
 } STRING;
 
 typedef struct BFF {
- STRING *bf;
- POINT b;
+ STRING *bf; /* bf[i] is the i-th line of the buffer */
+ POINT b;    /* cursor coordinates in window (at least in some contexts) */
  POINT mx; /* maximum column and line */
  int mxlines; /* number of lines */
  int cl, clsv;
