@@ -1,5 +1,5 @@
 /*
-	Allgemeine Makros
+   General Makros
 */
 
 #define isalnum1(x) ( isalnum(x) || (x) == '_')
