@@ -54,5 +54,35 @@
 #define ERR_NOTHING     8
 #define ERR_NOPROJECT   9
 
+/* errors defined in e_d_msg */
+#define ERR_CTRLCPRESS  0
+#define ERR_QUITDEBUG   1
+#define ERR_ENDDEBUG    2
+#define ERR_NOTRUNNING  3
+#define ERR_NOSYMBOL    4
+#define ERR_NOSOURCE    5
+#define ERR_STARTDEBUG  6
+#define ERR_CANTDEBUG   7
+#define ERR_STARTPROG   8
+#define ERR_CANTPROG    9
+#define ERR_PROGEXIT    10
+#define ERR_PROGTERM    11
+#define ERR_PROGSIGNAL  12
+#define ERR_UNKNOWNBRK  13
+#define ERR_CANTFILE    14
+#define ERR_CANTPIPE    15
+#define ERR_BREAKPOINT  16
+#define ERR_SIGNAL      17
+#define ERR_PROGEXIT2   18
+#define ERR_SIGNAL2     19
+#define ERR_INTERRUPT   20
+#define ERR_STOPPEDIN   21
+#define ERR_BREAKPOINT2 22
+#define ERR_NORMALTERM  23
+#define ERR_SOFTTERM    24
+#define ERR_CONTINUE    25
+#define ERR_NOSTACK     26
+#define ERR_NOPROCESS   27
+
 #endif
 
