@@ -32,7 +32,7 @@
 
 /*  XWindow Definitions  */
 
-#if defined(DJGPP) || !defined(NO_XWINDOWS)  || defined (GPM)
+#if defined(DJGPP) || !defined(NO_XWINDOWS)  || defined (HAVE_LIBGPM)
 #define MOUSE   1        /*  activate mouse  */
 #else
 #define MOUSE   0        /*  deactivate mouse  */
