@@ -48,5 +48,14 @@
 #define ED_MESSAGES_STOP_AT   0x0020
 #define ED_SYNTAX_HIGHLIGHT   0x0008
 
+#define ED_SHOW_ENDMARKS      0x0002
+
+#define ED_EDITOR_OPTIONS \
+  (ED_CUA_STYLE | ED_OLD_TILE_METHOD | ED_SOURCE_AUTO_INDENT | \
+  ED_ALWAYS_AUTO_INDENT | ED_SHOW_ENDMARKS)
+
+#define ED_PROGRAMMING_OPTIONS \
+  (ED_ERRORS_STOP_AT | ED_MESSAGES_STOP_AT | ED_SYNTAX_HIGHLIGHT)
+
 #endif
 
