@@ -9,18 +9,26 @@ char *strstr(char *s1, char *s2);
 char *getcwd(char *dir, int n);
 #endif
 
+#ifdef NCURSES
+#define e_putp(s) 1
+#else
 #define e_putp(s) tputs((s), 1, fk_u_putchar)
+#endif
 
 extern int cur_on;
 
 #ifdef DEFPGC
 #define getc(fp) fgetc((fp))
 #endif
+#ifdef NCURSES
+#define fk_getch() getch()
+#else
 #ifdef HAVE_LIBGPM
 #define fk_getch() Gpm_Getc(stdin)
 #else
 #define fk_getch() fgetc(stdin)
 #endif
+#endif
 #define WpeExit(n) e_exit((n))
 
 extern char *cur_rc, *cur_vs, *cur_nvs, *cur_vvs, *schirm;
