@@ -17,7 +17,7 @@ int e_blck_del(FENSTER *f)
  SCHIRM *s;
  int i,y,len;
 
- for (i = f->ed->mxedt; i > 0 && f->ed->f[i]->dtmd <= 'Z'; i--)
+ for (i = f->ed->mxedt; i > 0 && !DTMD_ISTEXT(f->ed->f[i]->dtmd); i--)
   ;
  if (i <= 0)
   return(0);
@@ -65,7 +65,7 @@ int e_blck_dup(char *dup, FENSTER *f)
  SCHIRM *s;
  int i;
 
- for (i = f->ed->mxedt; i > 0 && f->ed->f[i]->dtmd <= 'Z'; i--)
+ for (i = f->ed->mxedt; i > 0 && !DTMD_ISTEXT(f->ed->f[i]->dtmd); i--)
   ;
  if (i <= 0)
   return(0);
@@ -203,7 +203,7 @@ int e_edt_copy(FENSTER *f)
  BUFFER *b0 = f->ed->f[0]->b;
  int i, save;
 
- for (i = f->ed->mxedt; i > 0 && f->ed->f[i]->dtmd <= 'Z'; i--)
+ for (i = f->ed->mxedt; i > 0 && !DTMD_ISTEXT(f->ed->f[i]->dtmd); i--)
   ;
  if (i <= 0)
   return(0);
@@ -227,14 +227,14 @@ int e_edt_copy(FENSTER *f)
  return(0);
 }
 
-/*            Block Puffer in Fenster kopieren  */
+/*            Copy block buffer into window  */
 int e_edt_einf(FENSTER *f)
 {
  BUFFER *b;
  BUFFER *b0 = f->ed->f[0]->b;
  int i,y,len;
 
- for (i = f->ed->mxedt; i > 0 && f->ed->f[i]->dtmd <= 'Z'; i--)
+ for (i = f->ed->mxedt; i > 0 && !DTMD_ISTEXT(f->ed->f[i]->dtmd); i--)
   ;
  if (i <= 0)
   return(0);
@@ -271,7 +271,7 @@ int e_blck_move(FENSTER *f)
  int i;
  POINT ka;
 
- for (i = f->ed->mxedt; i > 0 && f->ed->f[i]->dtmd <= 'Z'; i--)
+ for (i = f->ed->mxedt; i > 0 && !DTMD_ISTEXT(f->ed->f[i]->dtmd); i--)
   ;
  if (i <= 0)
   return(0);
@@ -461,7 +461,7 @@ int e_blck_copy(FENSTER *f)
  BUFFER *b;
  int i;
 
- for (i = f->ed->mxedt; i > 0 && f->ed->f[i]->dtmd <= 'Z'; i--)
+ for (i = f->ed->mxedt; i > 0 && !DTMD_ISTEXT(f->ed->f[i]->dtmd); i--)
   ;
  if (i <= 0)
   return(0);
@@ -601,7 +601,7 @@ int e_blck_hide(FENSTER *f)
  SCHIRM *s;
  int i;
 
- for (i = f->ed->mxedt; i > 0 && f->ed->f[i]->dtmd <= 'Z'; i--)
+ for (i = f->ed->mxedt; i > 0 && !DTMD_ISTEXT(f->ed->f[i]->dtmd); i--)
   ;
  if (i <= 0)
   return(0);
@@ -620,7 +620,7 @@ int e_blck_begin(FENSTER *f)
 {
  int i;
 
- for (i = f->ed->mxedt; i > 0 && f->ed->f[i]->dtmd <= 'Z'; i--)
+ for (i = f->ed->mxedt; i > 0 && !DTMD_ISTEXT(f->ed->f[i]->dtmd); i--)
   ;
  if (i <= 0) return(0);
  e_switch_window(f->ed->edt[i], f);
@@ -630,12 +630,12 @@ int e_blck_begin(FENSTER *f)
  return(0);
 }
 
-/*           Block - Ende setzen   */
+/*           Set end of block   */
 int e_blck_end(FENSTER *f)
 {
  int i;
 
- for (i = f->ed->mxedt; i > 0 && f->ed->f[i]->dtmd <= 'Z'; i--)
+ for (i = f->ed->mxedt; i > 0 && !DTMD_ISTEXT(f->ed->f[i]->dtmd); i--)
   ;
  if (i <= 0)
   return(0);
@@ -651,7 +651,7 @@ int e_blck_gt_beg(FENSTER *f)
 {
  int i;
 
- for (i = f->ed->mxedt; i > 0 && f->ed->f[i]->dtmd <= 'Z'; i--)
+ for (i = f->ed->mxedt; i > 0 && !DTMD_ISTEXT(f->ed->f[i]->dtmd); i--)
   ;
  if (i <= 0)
   return(0);
@@ -667,7 +667,7 @@ int e_blck_gt_end(FENSTER *f)
 {
  int i;
 
- for (i = f->ed->mxedt; i > 0 && f->ed->f[i]->dtmd <= 'Z'; i--)
+ for (i = f->ed->mxedt; i > 0 && !DTMD_ISTEXT(f->ed->f[i]->dtmd); i--)
   ;
  if (i <= 0)
   return(0);
@@ -683,7 +683,7 @@ int e_blck_mrk_all(FENSTER *f)
 {
  int i;
 
- for (i = f->ed->mxedt; i > 0 && f->ed->f[i]->dtmd <= 'Z'; i--)
+ for (i = f->ed->mxedt; i > 0 && !DTMD_ISTEXT(f->ed->f[i]->dtmd); i--)
   ;
  if (i <= 0)
   return(0);
@@ -702,7 +702,7 @@ int e_blck_mrk_line(FENSTER *f)
 {
  int i;
 
- for (i = f->ed->mxedt; i > 0 && f->ed->f[i]->dtmd <= 'Z'; i--)
+ for (i = f->ed->mxedt; i > 0 && !DTMD_ISTEXT(f->ed->f[i]->dtmd); i--)
   ;
  if (i <= 0)
   return(0);
@@ -735,7 +735,7 @@ int e_blck_changecase(FENSTER *f, int mode)
  SCHIRM *screen;
  int i,x,y,x_begin,x_end;
 
- for (i = f->ed->mxedt; i > 0 && f->ed->f[i]->dtmd <= 'Z'; i--)
+ for (i = f->ed->mxedt; i > 0 && !DTMD_ISTEXT(f->ed->f[i]->dtmd); i--)
   ;
  if (i <= 0) return(0);
  e_switch_window(f->ed->edt[i], f);
@@ -805,7 +805,7 @@ int e_blck_to_left(FENSTER *f)
  int n = f->ed->tabn/2, i, j, k, l, m, nn;
  char *tstr = MALLOC((n+2)*sizeof(char));
 
- for(i = f->ed->mxedt; i > 0 && f->ed->f[i]->dtmd <= 'Z'; i--);
+ for(i = f->ed->mxedt; i > 0 && !DTMD_ISTEXT(f->ed->f[i]->dtmd); i--);
  if(i <= 0) return(0);
  e_switch_window(f->ed->edt[i], f);
  f = f->ed->f[f->ed->mxedt];
@@ -846,33 +846,39 @@ int e_blck_to_left(FENSTER *f)
 }
 
 /*   indent block   */
-int e_blck_to_right(f)
-     FENSTER *f;
+int e_blck_to_right(FENSTER *f)
 {
-   BUFFER *b;
-   SCHIRM *s;
-   int n = f->ed->tabn/2, i, j;
-   char *tstr = MALLOC((n+1)*sizeof(char));
-   for(i = f->ed->mxedt; i > 0 && f->ed->f[i]->dtmd <= 'Z'; i--);
-   if(i <= 0) return(0);
-   e_switch_window(f->ed->edt[i], f);
-   f = f->ed->f[f->ed->mxedt];
-   b = f->b;
-   s = f->s;
-   for(i = 0; i < n; i++) tstr[i] = ' ';
-   tstr[n] = '\0';
-   for(i = (!s->mark_begin.x) ? s->mark_begin.y : s->mark_begin.y + 1;
-			i < s->mark_end.y || (i == s->mark_end.y && s->mark_end.x > 0); i++)
-   {  for(j = 0; b->bf[i].len && isspace(b->bf[i].s[j]); j++);
-      e_ins_nchar(b, s, tstr, j, i, n);
-      if(i == s->mark_begin.y) s->mark_begin.x = 0;
-   }
-   FREE(tstr);
-   e_schirm(f, 1);
-   return(0);
+ BUFFER *b;
+ SCHIRM *s;
+ int n = f->ed->tabn/2, i, j;
+ char *tstr = MALLOC((n+1)*sizeof(char));
+
+ for (i = f->ed->mxedt; i > 0 && !DTMD_ISTEXT(f->ed->f[i]->dtmd); i--)
+  ;
+ if (i <= 0)
+  return(0);
+ e_switch_window(f->ed->edt[i], f);
+ f = f->ed->f[f->ed->mxedt];
+ b = f->b;
+ s = f->s;
+ for (i = 0; i < n; i++)
+  tstr[i] = ' ';
+ tstr[n] = '\0';
+ for (i = (!s->mark_begin.x) ? s->mark_begin.y : s->mark_begin.y + 1;
+   i < s->mark_end.y || (i == s->mark_end.y && s->mark_end.x > 0); i++)
+ {
+  for (j = 0; b->bf[i].len && isspace(b->bf[i].s[j]); j++)
+   ;
+  e_ins_nchar(b, s, tstr, j, i, n);
+  if (i == s->mark_begin.y)
+   s->mark_begin.x = 0;
+ }
+ FREE(tstr);
+ e_schirm(f, 1);
+ return(0);
 }
 
-/*            Block aus File einlesen   */
+/*            Read block from file   */
 int e_blck_read(FENSTER *f)
 {
  if (f->ins == 8)
@@ -897,7 +903,7 @@ int e_rep_search(FENSTER *f)
  FIND *fd = &(f->ed->fd);
  int i, ret, j, iend, jend, end;
 
- for (i = f->ed->mxedt; i > 0 && f->ed->f[i]->dtmd <= 'Z'; i--)
+ for (i = f->ed->mxedt; i > 0 && !DTMD_ISTEXT(f->ed->f[i]->dtmd); i--)
   ;
  if (i <= 0)
   return(0);
@@ -988,7 +994,7 @@ int e_goto_line(FENSTER *f)
  SCHIRM *s;
  BUFFER *b;
 
- for (i = f->ed->mxedt; i > 0 && f->ed->f[i]->dtmd <= 'Z'; i--)
+ for (i = f->ed->mxedt; i > 0 && !DTMD_ISTEXT(f->ed->f[i]->dtmd); i--)
   ;
  if (i <= 0)
   return(0);
@@ -1014,7 +1020,7 @@ int e_find(FENSTER *f)
 
  if (!o)
   return(-1);
- for (i = f->ed->mxedt; i > 0 && f->ed->f[i]->dtmd <= 'Z'; i--)
+ for (i = f->ed->mxedt; i > 0 && !DTMD_ISTEXT(f->ed->f[i]->dtmd); i--)
   ;
  if (i <= 0)
   return(0);
@@ -1095,7 +1101,7 @@ int e_replace(FENSTER *f)
 
  if (!o)
   return(-1);
- for (i = f->ed->mxedt; i > 0 && f->ed->f[i]->dtmd <= 'Z'; i--)
+ for (i = f->ed->mxedt; i > 0 && !DTMD_ISTEXT(f->ed->f[i]->dtmd); i--)
   ;
  if (i <= 0)
   return(0);
