@@ -36,9 +36,19 @@ int e_d_error(char *s);
 
 char *e_debugger, *e_deb_swtch = NULL, *e_d_save_schirm;
 int e_d_swtch = 0, rfildes[2], ofildes, e_d_pid = 0;
-int e_d_nbrpts = 0, e_d_nwtchs = 0, e_d_zwtchs = 0, *e_d_ybrpts, *e_d_nrbrpts, *e_d_nrwtchs;
+int e_d_nbrpts = 0, e_d_zwtchs = 0, *e_d_ybrpts, *e_d_nrbrpts;
+
+/* number of watch expressions in Watches window */
+int e_d_nwtchs = 0; 
+
+/* e_d_nrwtchs[i] is the y coordinate (count starts at 0) of the first line of
+   the i-th watch in the Watches window */
+int *e_d_nrwtchs; 
+
+char **e_d_swtchs; /* e_d_swtchs[i] is the i-th watch expression (a char*) */
+
 int e_d_nstack;
-char e_d_file[128], **e_d_sbrpts, **e_d_swtchs;
+char e_d_file[128], **e_d_sbrpts;
 char *e_d_out = NULL;
 int e_deb_type = 0, e_deb_mode = 0;
 char e_d_out_str[SVLINES][256];
@@ -52,8 +62,10 @@ extern BUFFER *e_p_w_buffer;
 extern char *att_no;
 extern char *e_tmp_dir;
 
+#ifdef NOTPARM
 char *tparm();
 char *tgoto();
+#endif
 #ifdef DEFTPUTS
 int tputs();
 #endif
@@ -576,11 +588,9 @@ int e_make_watches(FENSTER *f)
  char str[128];
  int i, y;
 
- for (i = f->ed->mxedt; i > 0 && strcmp(f->datnam, "Watches"); i--)
-  ;
- if (i > 0)
- {
-  for(y = 0; y < e_d_nwtchs && e_d_nrwtchs[y] < f->ed->f[i]->b->b.y; y++)
+ if ((f->ed->mxedt > 0) && (strcmp(f->datnam, "Watches") == 0))
+ { /* sets y=number of watch we're inserting */
+  for(y = 0; y < e_d_nwtchs && e_d_nrwtchs[y] < f->b->b.y; y++)
    ;
  }
  else
@@ -602,13 +612,22 @@ int e_make_watches(FENSTER *f)
    e_d_swtchs = REALLOC(e_d_swtchs, e_d_nwtchs * sizeof(char *));
    e_d_nrwtchs = REALLOC(e_d_nrwtchs, e_d_nwtchs * sizeof(int));
   }
+  
+  /*
+    move watch number y and following up one position so that we can insert 
+    at position y 
+  */
   for (i = e_d_nwtchs - 1; i > y; i--)
   {
    e_d_swtchs[i] = e_d_swtchs[i-1];
+   
+   /* The following instruction is pointless as e_d_nrwtchs[i] is invalidated
+      by inserting the new watch and has to be recomputed by e_d_p_watches()
+   */
    e_d_nrwtchs[i] = e_d_nrwtchs[i-1];
   }
-  e_d_swtchs[y] = MALLOC(strlen(str) + 1);
-  strcpy(e_d_swtchs[y], str);
+  e_d_swtchs[y] = MALLOC(strlen(str) + 1); /* insert...                    */
+  strcpy(e_d_swtchs[y], str);              /*       ... new watch at pos y */
   e_d_p_watches(f, 1);
   return(0);
  }
@@ -638,21 +657,26 @@ int e_edit_watches(FENSTER *f)
  return(-1);
 }
 
+/* Among other things, e_d_p_watches() must recompute e_d_nrwtchs when
+   called from e_edit_watches(), 
+   but has code paths that don't do this ==> possible BUG
+*/
 int e_d_p_watches(FENSTER *f, int sw)
 {
  ECNT *cn = f->ed;
  BUFFER *b;
  SCHIRM *s;
  int iw, i, k = 0, l, ret;
- char str1[256], *str = str1;
+ char str1[256], *str; /* is 256 always large enough? */
  char *str2;
 
  e_d_switch_out(0);
  if ((e_d_swtch > 2) && (e_d_p_stack(f, 0) == -1))
   return(-1);
+ /* Find the watch window */
  for (iw = cn->mxedt; iw > 0 && strcmp(cn->f[iw]->datnam, "Watches"); iw--);
  if (iw == 0 && !e_d_nwtchs)
- {
+ { /* if no watches and the mysterious iw!=0 then just repaint window tree */
   e_rep_win_tree(cn);
   return(0);
  }
@@ -670,12 +694,16 @@ int e_d_p_watches(FENSTER *f, int sw)
  f = cn->f[iw];
  b = cn->f[iw]->b;
  s = cn->f[iw]->s;
+ 
+ /* free all lines of BUFFER b */
  e_p_red_buffer(b);
  FREE(b->bf[0].s);
  b->mxlines=0;
 
  for (i = 0, l = 0; l < e_d_nwtchs; l++)
  {
+  str = str1;
+  
   /* Create appropriate command for the debugger */
   if (e_deb_type == 0 || e_deb_type == 3)
   {
@@ -706,13 +734,13 @@ int e_d_p_watches(FENSTER *f, int sw)
   {
    if (ret == -1)
    {
-    return(ret);
+    return(ret); /* BUG? e_d_nrwtchs not initialized if this return is taken */
    }
    str = MALLOC(strlen(str1) + 1);
    strcpy(str, str1);
    while ((ret = e_d_line_read(wfildes[0], str1, 256, 0, 0)) == 0 || ret == 2)
    {
-    if (ret == -1) return(ret);
+    if (ret == -1) return(ret); /* BUG? e_d_nrwtchs not initialized if this return is taken */
     if (ret == 2) e_d_error(str1);
     str = REALLOC(str, (k = strlen(str)) + strlen(str1) + 1);
     if (str[k-1] == '\n') str[k-1] = ' ';
@@ -751,8 +779,8 @@ int e_d_p_watches(FENSTER *f, int sw)
   str2 = WpeMalloc(strlen(e_d_swtchs[l]) + strlen(str + k) + 4);
   sprintf(str2, "%s: %s", e_d_swtchs[l], str + k);
 
+  e_d_nrwtchs[l] = b->mxlines;
   print_to_end_of_buffer(b, str2, b->mx.x);
-  e_d_nrwtchs[l] = b->mxlines-1;
 
   /* Free any allocated string */
   WpeFree(str2);
@@ -762,8 +790,9 @@ int e_d_p_watches(FENSTER *f, int sw)
   }
  }
 
+ e_new_line(b->mxlines, b);
  fk_cursor(1);
- if (b->b.y > i || sw) b->b.y = i;
+/* if (b->b.y > i || sw) b->b.y = i;*/
  if (sw && iw != cn->mxedt) e_switch_window(cn->edt[iw], cn->f[cn->mxedt]);
  else e_rep_win_tree(cn);
 /* e_d_switch_out(0);   */
