@@ -1503,10 +1503,11 @@ void e_cursor(FENSTER *f, int sw)
  int i, j;
 
  if (!DTMD_ISTEXT(f->dtmd)) return;
- if (b->b.y < 0) b->b.y = 0;
  if (b->b.y > b->mxlines-1) b->b.y = b->mxlines-1;
+ if (b->b.y < 0) b->b.y = 0;
  if (b->b.x < 0) b->b.x = 0;
- if (b->b.x > b->bf[b->b.y].len) b->b.x = b->bf[b->b.y].len;
+ if (b->mxlines==0) b->b.x=0; /* the else branch needs b->b.y < b->mxlines, which is not true for b->mxlines==0 */
+ else if (b->b.x > b->bf[b->b.y].len) b->b.x = b->bf[b->b.y].len;
  for (i = j = 0; i < b->b.x; i++)
  {
   if (*(b->bf[b->b.y].s + i) == WPE_TAB)
