@@ -219,11 +219,7 @@ int e_quit(FENSTER *f)
 #ifdef DEBUGGER
  extern int rfildes[], e_d_swtch;
 
- if (e_d_swtch)
- {
-  write(rfildes[1], "q\ny\n", 4);
-  e_d_swtch = 0;
- }
+ e_d_quit_basic(f);
 #endif
  for (i = cn->mxedt; i > 0; i--)
  {
