@@ -1,4 +1,4 @@
-#ifdef GPM
+#ifdef HAVE_LIBGPM
 /* we_gpm.c -- GPM routines for xwpe.
 
 Based on we_linux.c -- Created by Sebastiano Suraci */
