@@ -263,25 +263,12 @@ WOPT oblst_u[] = {  {"F1 Help",  0, 0, 2, F1},
 		    {"^F4 Close W.", 42, 0, 3, CF4},
 		    {"Alt-F4 Quit",  63, 0, 6, AF4}  };
 
-
-int main(int argc, char **argv)
+void ECNT_Init(ECNT *cn)
 {
- FARBE *fb;
- ECNT *cn;
- int i, err = 0, g[4];
- int so = 0, sd = 1;
- char *tp;
-
- e_ini_unix(&argc, argv);
- e_switch_screen(1);
- fb = e_ini_farbe();
- if ((cn = (ECNT *)MALLOC(sizeof(ECNT))) == NULL)
-  e_error(e_msg[ERR_LOWMEM], 2, fb);
- WpeEditor = cn;
  cn->mxedt = -1;
  cn->curedt = 0;
  cn->edt[0] = 0;
- cn->fb = fb;
+ cn->fb = NULL;
  cn->print_cmd = WpeStrdup(PRNTCMD);
 
  cn->dirct = WpeGetCurrentDir(cn);
@@ -310,12 +297,35 @@ int main(int argc, char **argv)
  cn->flopt = FM_REKURSIVE_ACTIONS | FM_REMOVE_INTO_WB | FM_MOVE_PROMPT |
    FM_MOVE_PROMPT | FM_PROMPT_DELETE;
  cn->edopt = ED_SOURCE_AUTO_INDENT | ED_ERRORS_STOP_AT | ED_SYNTAX_HIGHLIGHT;
+}
+
+int main(int argc, char **argv)
+{
+ FARBE *fb;
+ ECNT *cn;
+ int i, err = 0, g[4];
+ int so = 0, sd = 1;
+ char *tp;
+
+ if ((cn = (ECNT *)MALLOC(sizeof(ECNT))) == NULL)
+  e_error(e_msg[ERR_LOWMEM], 2, fb);
+ ECNT_Init(cn);
+ e_ini_unix(&argc, argv);
+ e_switch_screen(1);
+ fb = e_ini_farbe();
+ WpeEditor = cn;
+ cn->fb = fb;
+
  info_file = MALLOC((strlen(INFO_DIR)+1)*sizeof(char));
  strcpy(info_file, INFO_DIR);
  e_read_help_str();
  e_hlp = e_hlp_str[0];
  if (!(user_shell = getenv("SHELL"))) user_shell = DEF_SHELL;
-#ifdef HAVE_TEMPNAM
+#ifdef HAVE_MKDTEMP
+ e_tmp_dir = strdup("/tmp/xwpe_XXXXXX");
+ if (mkdtemp(e_tmp_dir) == NULL)
+#else
+#if defined(HAVE_TEMPNAM)
  e_tmp_dir = tempnam(NULL, "xwpe_");
 #else
  e_tmp_dir = MALLOC(128);
@@ -323,6 +333,7 @@ int main(int argc, char **argv)
  e_tmp_dir = REALLOC(e_tmp_dir, (strlen(e_tmp_dir)+1)*sizeof(char));
 #endif
  if ((e_tmp_dir == NULL) || (mkdir(e_tmp_dir, 0700) != 0))
+#endif
  {
   perror("Xwpe: ");
   return 1;
@@ -389,15 +400,7 @@ int main(int argc, char **argv)
  {
   if (*argv[i] == '-')
   {
-   if (*(argv[i]+1) == 'n')
-   {
-    if (*(argv[i]+2) == 'c') cn->maxcol = atoi(argv[i+1]);
-    else if (*(argv[i]+2) == 'u') cn->numundo = atoi(argv[i+1]);
-    else if (*(argv[i]+2) == 'm') cn->maxchg = atoi(argv[i+1]);
-    else i--;
-    i++;
-   }
-   else if (*(argv[i]+1) == 's' && *(argv[i]+2) == 'f') i++;
+   if (*(argv[i]+1) == 's' && *(argv[i]+2) == 'f') i++;
 #if defined(UNIX) && defined(PROG)
    else if (*(argv[i]+1) == 'p' && *(argv[i]+2) == 'm') e_we_sw |= 8;
 #endif
@@ -495,51 +498,56 @@ void e_ini_desk(ECNT *cn)
  e_pr_uul(cn->fb);
 }
 
+void FARBE_Init(FARBE *fb)
+{
+ fb->er = e_s_x_clr(15,4);  /*  Editor Frames         */
+ fb->et = e_s_x_clr(11,4);  /*  Editor Text           */
+ fb->ez = e_s_x_clr(4,7);   /*  Editors Text highlighted  */
+ fb->es = e_s_x_clr(10,4);  /*  Editors Window-Button */
+ fb->ek = e_s_x_clr(11,6);  /*  Editors highlighted (find) */
+ fb->em = e_s_x_clr(4,6);   /*  Mouse slider bar         */
+ fb->mr = e_s_x_clr(0,7);   /*  Menu Frame             */
+ fb->mt = e_s_x_clr(0,7);   /*  Menu Text               */
+ fb->mz = e_s_x_clr(0,2);   /*  Menu Text highlighted      */
+ fb->ms = e_s_x_clr(1,7);   /*  Menu-Switch           */
+ fb->nr = e_s_x_clr(15,7);  /*  Options Frame         */
+ fb->nt = e_s_x_clr(0,7);   /*  Options Text           */
+ fb->nsnt = e_s_x_clr(11,7);/*  Options Text-Switch  */
+ fb->ne = e_s_x_clr(1, 7);  /*  Options Window-Button */
+ fb->fr = e_s_x_clr(15,4);  /*  Editor Control Bar (?) (Schreibleiste) passive */
+ fb->fa = e_s_x_clr(15,2);  /*  Editor Control Bar (?) (Schreibleiste) active */
+ fb->ft = e_s_x_clr(0,6);   /*  Data Text		  */
+ fb->fz = e_s_x_clr(15,2);  /*  Data active highlighted	  */
+ fb->frft = e_s_x_clr(15,6);/*  Data passive highlighted	  */
+ fb->fs = e_s_x_clr(0,6);   /*  Switch Text		  */
+ fb->nsft = e_s_x_clr(14,6);/*  Switch Switch	  */
+ fb->fsm = e_s_x_clr(14,6); /*  Switch active	  */
+ fb->nz = e_s_x_clr(15,2);  /*  Button Text             */
+ fb->ns = e_s_x_clr(11,2);  /*  Button Switch         */
+ fb->nm = e_s_x_clr(11,2);  /*  Button Text highlighted    */
+ fb->hh = e_s_x_clr(12,6);  /*  Help Header		  */
+ fb->hb = e_s_x_clr(11,2);  /*  Help Button		  */
+ fb->hm = e_s_x_clr(10,4);  /*  Help highlighted		  */
+ fb->df = e_s_x_clr(7,0);   /*  Background		  */
+ fb->of = e_s_x_clr(8,0);   /*  void	(unused)	  */
+ fb->db = e_s_x_clr(0,1);   /*  Breakpoint		  	  */
+ fb->dy = e_s_x_clr(12,6);  /*  Debugger Stop		  */
+ fb->ct = e_s_x_clr(11, 4); /*  C-Prog. Text                 */
+ fb->cr = e_s_x_clr(15, 4); /*  C-Prog. res. Words           */
+ fb->ck = e_s_x_clr(14, 4); /*  C-Prog. Constants           */
+ fb->cp = e_s_x_clr(10, 4); /*  C-Prog. Pre-processor         */
+ fb->cc = e_s_x_clr( 7, 4); /*  C-Prog. Comments               */
+ fb->dc = ' ';
+ fb->ws = 7;
+}
+
 FARBE *e_ini_farbe()
 {
  if (WpeIsXwin())
  {
   if (!x_fb)
    x_fb = WpeMalloc(sizeof(FARBE));
-  x_fb->er = e_s_x_clr(15,1);   /*  Editor Frames         */
-  x_fb->et = e_s_x_clr(14,1);   /*  Editor Text           */
-  x_fb->ez = e_s_x_clr(1,7);    /*  Editors Text highlighted  */
-  x_fb->es = e_s_x_clr(10,1);   /*  Editors Window-Button */
-  x_fb->ek = e_s_x_clr(14,3);   /*  Editors highlighted (find) */
-  x_fb->em = e_s_x_clr(1,3);    /*  Mouse slider bar         */
-  x_fb->mr = e_s_x_clr(0,7);    /*  Menu Frame             */
-  x_fb->mt = e_s_x_clr(0,7);    /*  Menu Text               */
-  x_fb->mz = e_s_x_clr(0,2);    /*  Menu Text highlighted      */
-  x_fb->ms = e_s_x_clr(4,7);    /*  Menu-Switch           */
-  x_fb->nr = e_s_x_clr(15,7);   /*  Options Frame         */
-  x_fb->nt = e_s_x_clr(0,7);    /*  Options Text           */
-  x_fb->nsnt = e_s_x_clr(14,7); /*  Options Text-Switch  */
-  x_fb->ne = e_s_x_clr(4, 7);   /*  Options Window-Button */
-  x_fb->fr = e_s_x_clr(15,1);   /*  Editor Control Bar (?) (Schreibleiste) passive */
-  x_fb->fa = e_s_x_clr(15,2);   /*  Editor Control Bar (?) (Schreibleiste) active */
-  x_fb->ft = e_s_x_clr(0,3);    /*  Data Text		  */
-  x_fb->fz = e_s_x_clr(15,2);   /*  Data active highlighted	  */
-  x_fb->frft = e_s_x_clr(15,3); /*  Data passive highlighted	  */
-  x_fb->fs = e_s_x_clr(0,3);    /*  Switch Text		  */
-  x_fb->nsft = e_s_x_clr(14,3); /*  Switch Switch	  */
-  x_fb->fsm = e_s_x_clr(14,3);  /*  Switch active	  */
-  x_fb->nz = e_s_x_clr(15,2);   /*  Button Text             */
-  x_fb->ns = e_s_x_clr(14,2);   /*  Button Switch         */
-  x_fb->nm = e_s_x_clr(14,2);   /*  Button Text highlighted    */
-  x_fb->hh = e_s_x_clr(9,3);    /*  Help Header		  */
-  x_fb->hb = e_s_x_clr(14,2);   /*  Help Button		  */
-  x_fb->hm = e_s_x_clr(10,1);   /*  Help highlighted		  */
-  x_fb->df = e_s_x_clr(7,0);    /*  Background		  */
-  x_fb->of = e_s_x_clr(8,0);    /*  void	(unused)	  */
-  x_fb->db = e_s_x_clr(0,4);    /*  Breakpoint		  	  */
-  x_fb->dy = e_s_x_clr(9,3);    /*  Debugger Stop		  */
-  x_fb->ct = e_s_x_clr(14, 1);  /*  C-Prog. Text                 */
-  x_fb->cr = e_s_x_clr(15, 1);  /*  C-Prog. res. Words           */
-  x_fb->ck = e_s_x_clr(11, 1);  /*  C-Prog. Constants           */
-  x_fb->cp = e_s_x_clr(10, 1);  /*  C-Prog. Pre-processor         */
-  x_fb->cc = e_s_x_clr( 7, 1);  /*  C-Prog. Comments                                             */
-  x_fb->dc = 0x02;
-  x_fb->ws = 7;
+  FARBE_Init(x_fb);
   return x_fb;
  }
  else
@@ -548,45 +556,7 @@ FARBE *e_ini_farbe()
    u_fb = WpeMalloc(sizeof(FARBE));
   if (col_num)
   {
-   u_fb->er = e_s_x_clr(15,4);  /*  Editor Frames         */
-   u_fb->et = e_s_x_clr(11,4);  /*  Editor Text           */
-   u_fb->ez = e_s_x_clr(4,7);   /*  Editors Text highlighted  */
-   u_fb->es = e_s_x_clr(10,4);  /*  Editors Window-Button */
-   u_fb->ek = e_s_x_clr(11,6);  /*  Editors highlighted (find) */
-   u_fb->em = e_s_x_clr(4,6);   /*  Mouse slider bar         */
-   u_fb->mr = e_s_x_clr(0,7);   /*  Menu Frame             */
-   u_fb->mt = e_s_x_clr(0,7);   /*  Menu Text               */
-   u_fb->mz = e_s_x_clr(0,2);   /*  Menu Text highlighted      */
-   u_fb->ms = e_s_x_clr(1,7);   /*  Menu-Switch           */
-   u_fb->nr = e_s_x_clr(15,7);  /*  Options Frame         */
-   u_fb->nt = e_s_x_clr(0,7);   /*  Options Text           */
-   u_fb->nsnt = e_s_x_clr(11,7);/*  Options Text-Switch  */
-   u_fb->ne = e_s_x_clr(1, 7);  /*  Options Window-Button */
-   u_fb->fr = e_s_x_clr(15,4);  /*  Editor Control Bar (?) (Schreibleiste) passive */
-   u_fb->fa = e_s_x_clr(15,2);  /*  Editor Control Bar (?) (Schreibleiste) active */
-   u_fb->ft = e_s_x_clr(0,6);   /*  Data Text		  */
-   u_fb->fz = e_s_x_clr(15,2);  /*  Data active highlighted	  */
-   u_fb->frft = e_s_x_clr(15,6);/*  Data passive highlighted	  */
-   u_fb->fs = e_s_x_clr(0,6);   /*  Switch Text		  */
-   u_fb->nsft = e_s_x_clr(14,6);/*  Switch Switch	  */
-   u_fb->fsm = e_s_x_clr(14,6); /*  Switch active	  */
-   u_fb->nz = e_s_x_clr(15,2);  /*  Button Text             */
-   u_fb->ns = e_s_x_clr(11,2);  /*  Button Switch         */
-   u_fb->nm = e_s_x_clr(11,2);  /*  Button Text highlighted    */
-   u_fb->hh = e_s_x_clr(12,6);  /*  Help Header		  */
-   u_fb->hb = e_s_x_clr(11,2);  /*  Help Button		  */
-   u_fb->hm = e_s_x_clr(10,4);  /*  Help highlighted		  */
-   u_fb->df = e_s_x_clr(7,0);   /*  Background		  */
-   u_fb->of = e_s_x_clr(8,0);   /*  void	(unused)	  */
-   u_fb->db = e_s_x_clr(0,1);   /*  Breakpoint		  	  */
-   u_fb->dy = e_s_x_clr(12,6);  /*  Debugger Stop		  */
-   u_fb->ct = e_s_x_clr(11, 4); /*  C-Prog. Text                 */
-   u_fb->cr = e_s_x_clr(15, 4); /*  C-Prog. res. Words           */
-   u_fb->ck = e_s_x_clr(14, 4); /*  C-Prog. Constants           */
-   u_fb->cp = e_s_x_clr(10, 4); /*  C-Prog. Pre-processor         */
-   u_fb->cc = e_s_x_clr( 7, 4); /*  C-Prog. Comments                                             */
-   u_fb->dc = ' ';
-   u_fb->ws = 7;
+   FARBE_Init(u_fb);
   }
   else
   {
