@@ -70,31 +70,29 @@ int WpeHandleMainmenu(int n, FENSTER *f)
   mainmenu[1].position = -3;
 #ifdef UNIX
   mainmenu[1].width = 24;
-  mainmenu[1].no_of_items = 12;
+  mainmenu[1].no_of_items = 11;
   if((mainmenu[1].menuitems = MALLOC(mainmenu[1].no_of_items * sizeof(OPTK))) == NULL)
     e_error(e_msg[ERR_LOWMEM], 1, f->fb);
   if(f->ed->edopt & ED_CUA_STYLE)
   {
     mainmenu[1].menuitems[0] = WpeFillSubmenuItem("File-Manager     F2", 0, 'M', WpeManager);
-    mainmenu[1].menuitems[1] = WpeFillSubmenuItem("ADd F.-Mng Shift F2", 1, 'D', WpeManagerFirst);
-    mainmenu[1].menuitems[3] = WpeFillSubmenuItem("Save         Alt F2", 0, 'S', e_m_save);
-    mainmenu[1].menuitems[11] = WpeFillSubmenuItem("Quit         Alt F4", 0, 'Q', e_quit);
+    mainmenu[1].menuitems[2] = WpeFillSubmenuItem("Save         Alt F2", 0, 'S', e_m_save);
+    mainmenu[1].menuitems[10] = WpeFillSubmenuItem("Quit         Alt F4", 0, 'Q', e_quit);
   }
   else
   {
     mainmenu[1].menuitems[0] = WpeFillSubmenuItem("File-Manager     F3", 0, 'M', WpeManager);
-    mainmenu[1].menuitems[1] = WpeFillSubmenuItem("ADd F.-Mng  Ctrl F3", 1, 'D', WpeManagerFirst);
-    mainmenu[1].menuitems[3] = WpeFillSubmenuItem("Save             F2", 0, 'S', e_m_save);
-    mainmenu[1].menuitems[11] = WpeFillSubmenuItem("Quit          Alt X", 0, 'Q', e_quit);
+    mainmenu[1].menuitems[2] = WpeFillSubmenuItem("Save             F2", 0, 'S', e_m_save);
+    mainmenu[1].menuitems[10] = WpeFillSubmenuItem("Quit          Alt X", 0, 'Q', e_quit);
   }
-  mainmenu[1].menuitems[2] = WpeFillSubmenuItem("New", 0, 'N', e_new);
-  mainmenu[1].menuitems[4] = WpeFillSubmenuItem("Save As", 5, 'A', WpeSaveAsManager);
-  mainmenu[1].menuitems[5] = WpeFillSubmenuItem("Save aLl", 6, 'L', e_saveall);
-  mainmenu[1].menuitems[6] = WpeFillSubmenuItem("Execute", 0, 'E', WpeExecuteManager);
-  mainmenu[1].menuitems[7] = WpeFillSubmenuItem("SHell", 1, 'H', WpeShell);
-  mainmenu[1].menuitems[8] = WpeFillSubmenuItem("Find", 0, 'F', WpeFindWindow);
-  mainmenu[1].menuitems[9] = WpeFillSubmenuItem("Grep", 0, 'G', WpeGrepWindow);
-  mainmenu[1].menuitems[10] = WpeFillSubmenuItem("Print File", 0, 'P', WpePrintFile);
+  mainmenu[1].menuitems[1] = WpeFillSubmenuItem("New", 0, 'N', e_new);
+  mainmenu[1].menuitems[3] = WpeFillSubmenuItem("Save As", 5, 'A', WpeSaveAsManager);
+  mainmenu[1].menuitems[4] = WpeFillSubmenuItem("Save aLl", 6, 'L', e_saveall);
+  mainmenu[1].menuitems[5] = WpeFillSubmenuItem("Execute", 0, 'E', WpeExecuteManager);
+  mainmenu[1].menuitems[6] = WpeFillSubmenuItem("SHell", 1, 'H', WpeShell);
+  mainmenu[1].menuitems[7] = WpeFillSubmenuItem("Find", 0, 'F', WpeFindWindow);
+  mainmenu[1].menuitems[8] = WpeFillSubmenuItem("Grep", 0, 'G', WpeGrepWindow);
+  mainmenu[1].menuitems[9] = WpeFillSubmenuItem("Print File", 0, 'P', WpePrintFile);
 #endif
   mainmenu[2].position = -3;
   mainmenu[2].width = 27;
