@@ -62,7 +62,7 @@ int e_m2_mouse(int xa, int ya, int xe, int ye, OPTK *fopt)
  return(c);
 }
 
-/*	Maus-Hilfsleisten-Steuerung       */
+/*      Mouse assistant bar control       */
 int e_m3_mouse()
 {
  extern WOPT *blst;
@@ -318,26 +318,22 @@ int WpeMouseInFileDirList(int k, int sw, FENSTER * f)
 
 
 /*  File Window  */
-char *e_gt_btstr(x, y, n, buffer)
-     int x;
-     int y;
-     int n;
-     char *buffer;
+char *e_gt_btstr(int x, int y, int n, char *buffer)
 {
-   int i;
-   for(i = 0; i < n; i++) buffer[i] = e_gt_byte(2*x + i, y);
-   return(buffer);
+ int i;
+
+ for (i = 0; i < n; i++) buffer[i] = e_gt_byte(2*x + i, y)
+  ;
+ return(buffer);
 }
 
-char *e_pt_btstr(x, y, n, buffer)
-     int x;
-     int y;
-     int n;
-     char *buffer;
+char *e_pt_btstr(int x, int y, int n, char *buffer)
 {
-   int i;
-   for(i = 0; i < n; i++) e_pt_byte(2*x + i, y, buffer[i]);
-   return(buffer);
+ int i;
+
+ for(i = 0; i < n; i++) e_pt_byte(2*x + i, y, buffer[i])
+  ;
+ return(buffer);
 }
 
 int fl_wnd_mouse(sw, k, fw)
@@ -550,9 +546,9 @@ void e_eck_mouse(FENSTER *f, int sw)
  xold = g[2]/8;
  yold = g[3]/8;
  xa = xold - f->a.x;
- if (f->dtmd == 'M')
+ if (f->dtmd == DTMD_FILEDROPDOWN)
   xmin = 15;
- else if(f->dtmd <= 'Z')
+ else if (!DTMD_ISTEXT(f->dtmd))
   ymin = 9;
  while(g[1] != 0)
  {
@@ -625,7 +621,7 @@ void e_eck_mouse(FENSTER *f, int sw)
    f->pic = e_ed_kst(f, f->pic, 0);
    if (f->pic == NULL)
     e_error(e_msg[ERR_LOWMEM], 1, f->fb);
-   if (f->dtmd == 'M')
+   if (f->dtmd == DTMD_FILEDROPDOWN)
    {
     FLWND *fw = (FLWND*) f->b;
     fw->xa = f->a.x+1;
@@ -648,165 +644,183 @@ void e_eck_mouse(FENSTER *f, int sw)
  e_ed_rahmen(f, 1);
 }
 
-/*       Maus-Edit-Fenster-Steuerung   */
+/*       Mouse edit window control   */
 int e_edt_mouse(int c, FENSTER *f)
 {
-   int i, ret = 0;
-   extern struct mouse e_mouse;
-   ECNT *cn = f->ed;
-   if(e_mouse.y == 0) return(e_m1_mouse());
-   else if(e_mouse.y == MAXSLNS-1) return(e_m3_mouse());
-   else if(e_mouse.x >= f->a.x && e_mouse.x <= f->e.x
-	   && e_mouse.y >= f->a.y && e_mouse.y <= f->e.y)
-   {  if(e_mouse.x == f->a.x+3 && e_mouse.y == f->a.y) ret = f->ed->edopt & ED_CUA_STYLE ? CF4 : AF3;
-      else if(e_mouse.x == f->e.x-3 && e_mouse.y == f->a.y) e_ed_zoom(f);
-      else if(e_mouse.x == f->a.x && e_mouse.y == f->a.y) e_eck_mouse(f, 1);
-      else if(e_mouse.x == f->e.x && e_mouse.y == f->a.y) e_eck_mouse(f, 2);
-      else if(e_mouse.x == f->e.x && e_mouse.y == f->e.y) e_eck_mouse(f, 3);
-      else if(e_mouse.x == f->a.x && e_mouse.y == f->e.y) e_eck_mouse(f, 4);
-      else if(e_mouse.y == f->a.y) e_eck_mouse(f, 0);
-      else if(e_mouse.x == f->a.x && e_mouse.y == f->a.y+2) ret = f->ed->edopt & ED_CUA_STYLE ? AF3 : F4;
-      else if(e_mouse.x == f->a.x && e_mouse.y == f->a.y+4) ret = f->ed->edopt & ED_CUA_STYLE ? CF3 : AF4;
-      else if(e_mouse.x == f->a.x && e_mouse.y == f->a.y+6) ret = f->ed->edopt & ED_CUA_STYLE ? F3 : CF4;
-      else if(f->ins != 8 && e_mouse.x == f->a.x
-				&& e_mouse.y == f->a.y+8) ret = f->ed->edopt & ED_CUA_STYLE ? AF2 : F2;
-      else if(e_mouse.y == f->e.y && e_mouse.x > f->a.x + 4
-				&& e_mouse.x < f->a.x + 14) ret = AltG;
-      else if(e_mouse.y == f->e.y && e_mouse.x == f->a.x + 15 && f->ins != 8)
-      {  if(f->ins & 1) f->ins &= ~1;
-	 else f->ins |= 1;
-	 e_pr_filetype(f);
-      }
-      else if(e_mouse.y == f->e.y && e_mouse.x == f->a.x + 16 && f->ins != 8)
-      {  if(f->ins & 2) f->ins &= ~2;
-	 else f->ins |= 2;
-	 e_pr_filetype(f);
-      }
-      else if(e_mouse.x > f->a.x && e_mouse.x < f->e.x
-	       && e_mouse.y > f->a.y && e_mouse.y < f->e.y)
-      {  if(c < -1) ret = e_ccp_mouse(c, f);
-	 else if(f->dtmd == 'h' && f->ins == 8
-		&& f->b->b.y == e_mouse.y-f->a.y+NUM_LINES_OFF_SCREEN_TOP-1
-		&& ((i = f->b->b.x) == e_mouse_cursor(f->b, f->s, f)))
-	 ret = WPE_CR;
-	 else
+ int i, ret = 0;
+ extern struct mouse e_mouse;
+ ECNT *cn = f->ed;
+
+ if (e_mouse.y == 0) return(e_m1_mouse());
+ else if (e_mouse.y == MAXSLNS-1) return(e_m3_mouse());
+ else if (e_mouse.x >= f->a.x && e_mouse.x <= f->e.x &&
+   e_mouse.y >= f->a.y && e_mouse.y <= f->e.y)
+ {
+  if (e_mouse.x == f->a.x+3 && e_mouse.y == f->a.y) ret = f->ed->edopt & ED_CUA_STYLE ? CF4 : AF3;
+  else if (e_mouse.x == f->e.x-3 && e_mouse.y == f->a.y) e_ed_zoom(f);
+  else if (e_mouse.x == f->a.x && e_mouse.y == f->a.y) e_eck_mouse(f, 1);
+  else if (e_mouse.x == f->e.x && e_mouse.y == f->a.y) e_eck_mouse(f, 2);
+  else if (e_mouse.x == f->e.x && e_mouse.y == f->e.y) e_eck_mouse(f, 3);
+  else if (e_mouse.x == f->a.x && e_mouse.y == f->e.y) e_eck_mouse(f, 4);
+  else if (e_mouse.y == f->a.y) e_eck_mouse(f, 0);
+  else if (e_mouse.x == f->a.x && e_mouse.y == f->a.y+2) ret = f->ed->edopt & ED_CUA_STYLE ? AF3 : F4;
+  else if (e_mouse.x == f->a.x && e_mouse.y == f->a.y+4) ret = f->ed->edopt & ED_CUA_STYLE ? CF3 : AF4;
+  else if (e_mouse.x == f->a.x && e_mouse.y == f->a.y+6) ret = f->ed->edopt & ED_CUA_STYLE ? F3 : CF4;
+  else if (f->ins != 8 && e_mouse.x == f->a.x &&
+    e_mouse.y == f->a.y+8) ret = f->ed->edopt & ED_CUA_STYLE ? AF2 : F2;
+  else if (e_mouse.y == f->e.y && e_mouse.x > f->a.x + 4 &&
+    e_mouse.x < f->a.x + 14) ret = AltG;
+  else if (e_mouse.y == f->e.y && e_mouse.x == f->a.x + 15 && f->ins != 8)
+  {
+   if (f->ins & 1) f->ins &= ~1;
+   else f->ins |= 1;
+   e_pr_filetype(f);
+  }
+  else if (e_mouse.y == f->e.y && e_mouse.x == f->a.x + 16 && f->ins != 8)
+  {
+   if (f->ins & 2) f->ins &= ~2;
+   else f->ins |= 2;
+   e_pr_filetype(f);
+  }
+  else if (e_mouse.x > f->a.x && e_mouse.x < f->e.x &&
+    e_mouse.y > f->a.y && e_mouse.y < f->e.y)
+  {
+   if (c < -1) ret = e_ccp_mouse(c, f);
+   else if (f->dtmd == DTMD_HELP && f->ins == 8 &&
+     f->b->b.y == e_mouse.y-f->a.y+NUM_LINES_OFF_SCREEN_TOP-1 &&
+     ((i = f->b->b.x) == e_mouse_cursor(f->b, f->s, f)))
+    ret = WPE_CR;
+   else
 #ifdef PROG
 #ifdef DEBUGGER
-	 {  if(WpeIsProg() && (!strcmp(f->datnam, "Watches") ||
-	      	!strcmp(f->datnam, "Messages") ||
-       		!strcmp(f->datnam, "Stack"))) ret = e_d_car_mouse(f);
-	    else  e_cur_mouse(f);
-	 }
+   {
+    if (WpeIsProg() && (!strcmp(f->datnam, "Watches") ||
+      !strcmp(f->datnam, "Messages") ||
+      !strcmp(f->datnam, "Stack")))
+     ret = e_d_car_mouse(f);
+    else
+     e_cur_mouse(f);
+   }
 #else
-	 {  if(WpeIsProg() && !strcmp(f->datnam, "Messages"))
-	    ret = e_d_car_mouse(f);
-	    else  e_cur_mouse(f);
-	 }
+   {
+    if (WpeIsProg() && !strcmp(f->datnam, "Messages"))
+     ret = e_d_car_mouse(f);
+    else
+     e_cur_mouse(f);
+   }
 #endif
 #else
-	 e_cur_mouse(f);
+    e_cur_mouse(f);
 #endif
-      }
-      else if(e_mouse.x == f->e.x && e_mouse.y == f->a.y+1)
-      {
-	/*changed the while()... to a do...while();  :Mark L*/
-	do
-	 {  f->b->b.y = f->b->b.y > 0 ? f->b->b.y - 1 : 0;
-	    f->b->b.x = e_chr_sp(f->b->clsv, f->b, f);
-	    e_cursor(f, 1);
-	    e_refresh();
-	 }
-	while(e_mshit());
-      }
-      else if(e_mouse.x == f->e.x && e_mouse.y == f->e.y-1)
-      {
-	/*changed the while()... to a do...while();  :Mark L*/
-	do
-	 {  f->b->b.y = f->b->b.y < f->b->mxlines - 1 ?
-				f->b->b.y + 1 : f->b->mxlines - 1;
-	    f->b->b.x = e_chr_sp(f->b->clsv, f->b, f);
-	    e_cursor(f, 1);
-	    e_refresh();
-	 }
-	while(e_mshit());
-      }
-      else if(e_mouse.x == f->e.x
-	    && e_mouse.y > f->a.y+1 && e_mouse.y < f->e.y-1)
-      {  f->b->b.y = e_lst_mouse(f->e.x, f->a.y+1, f->e.y-f->a.y-1, 0,
-						f->b->mxlines, f->b->b.y);
-	 e_cursor(f, 1);
-	 e_refresh();
-      }
-      else if(e_mouse.y == f->e.y && e_mouse.x == f->a.x+19)
-      {  while(e_mshit())
-	 {  f->b->b.x = f->b->b.x > 0 ? f->b->b.x - 1 : 0;
-	    e_cursor(f, 1);
-	    e_refresh();
-	 }
-      }
-      else if(e_mouse.y == f->e.y && e_mouse.x == f->e.x-2)
-      {  while(e_mshit())
-	 {  f->b->b.x = f->b->b.x < f->b->bf[f->b->b.y].len ?
-				f->b->b.x + 1 : f->b->bf[f->b->b.y].len;
-	    e_cursor(f, 1);
-	    e_refresh();
-	 }
-      }
-      else if(e_mouse.y == f->e.y
-	    && e_mouse.x > f->a.x+19 && e_mouse.x < f->e.x-2)
-      {  f->b->b.x = e_lst_mouse(f->a.x+19, f->e.y, f->e.x-f->a.x-20, 1,
-					     f->b->mx.x, NUM_COLS_OFF_SCREEN_LEFT);
-	 e_cursor(f, 1);
-	 e_refresh();
-      }
+  }
+  else if (e_mouse.x == f->e.x && e_mouse.y == f->a.y+1)
+  {
+   /*changed the while()... to a do...while();  :Mark L*/
+   do
+   {
+    f->b->b.y = f->b->b.y > 0 ? f->b->b.y - 1 : 0;
+    f->b->b.x = e_chr_sp(f->b->clsv, f->b, f);
+    e_cursor(f, 1);
+    e_refresh();
+   } while(e_mshit());
+  }
+  else if (e_mouse.x == f->e.x && e_mouse.y == f->e.y-1)
+  {
+   /*changed the while()... to a do...while();  :Mark L*/
+   do
+   {
+    f->b->b.y = f->b->b.y < f->b->mxlines - 1 ?
+      f->b->b.y + 1 : f->b->mxlines - 1;
+    f->b->b.x = e_chr_sp(f->b->clsv, f->b, f);
+    e_cursor(f, 1);
+    e_refresh();
+   } while(e_mshit());
+  }
+  else if (e_mouse.x == f->e.x &&
+    e_mouse.y > f->a.y+1 && e_mouse.y < f->e.y-1)
+  {
+   f->b->b.y = e_lst_mouse(f->e.x, f->a.y+1, f->e.y-f->a.y-1, 0,
+     f->b->mxlines, f->b->b.y);
+   e_cursor(f, 1);
+   e_refresh();
+  }
+  else if (e_mouse.y == f->e.y && e_mouse.x == f->a.x+19)
+  {
+   while (e_mshit())
+   {
+    f->b->b.x = f->b->b.x > 0 ? f->b->b.x - 1 : 0;
+    e_cursor(f, 1);
+    e_refresh();
    }
-   else
-   {  for(i = cn->mxedt; i > 0; i--)
-      {  if(e_mouse.x >= cn->f[i]->a.x && e_mouse.x <= cn->f[i]->e.x
-	   && e_mouse.y >= cn->f[i]->a.y && e_mouse.y <= cn->f[i]->e.y)
-	 {  ret = cn->edt[i] < 10 ? Alt1-1+cn->edt[i] : 1014+cn->edt[i];
-	    break;
-	 }
-      }
+  }
+  else if (e_mouse.y == f->e.y && e_mouse.x == f->e.x-2)
+  {
+   while (e_mshit())
+   {
+    f->b->b.x = f->b->b.x < f->b->bf[f->b->b.y].len ?
+      f->b->b.x + 1 : f->b->bf[f->b->b.y].len;
+    e_cursor(f, 1);
+    e_refresh();
    }
-   while(e_mshit()!= 0);
-   return(ret);
+  }
+  else if (e_mouse.y == f->e.y &&
+    e_mouse.x > f->a.x+19 && e_mouse.x < f->e.x-2)
+  {
+   f->b->b.x = e_lst_mouse(f->a.x+19, f->e.y, f->e.x-f->a.x-20, 1,
+     f->b->mx.x, NUM_COLS_OFF_SCREEN_LEFT);
+   e_cursor(f, 1);
+   e_refresh();
+  }
+ }
+ else
+ {
+  for (i = cn->mxedt; i > 0; i--)
+  {
+   if (e_mouse.x >= cn->f[i]->a.x && e_mouse.x <= cn->f[i]->e.x &&
+     e_mouse.y >= cn->f[i]->a.y && e_mouse.y <= cn->f[i]->e.y)
+   {
+    ret = cn->edt[i] < 10 ? Alt1-1+cn->edt[i] : 1014+cn->edt[i];
+    break;
+   }
+  }
+ }
+ while (e_mshit()!= 0)
+  ;
+ return(ret);
 }
 
-int e_mouse_cursor(b, s, f)
-     BUFFER *b;
-     SCHIRM *s;
-     FENSTER *f;
+int e_mouse_cursor(BUFFER *b, SCHIRM *s, FENSTER *f)
 {
-   extern struct mouse e_mouse;
-   b->b.x = e_mouse.x-f->a.x+s->c.x-1;
-   b->b.y = e_mouse.y-f->a.y+s->c.y-1;
-   if(b->b.y < 0) b->b.y = 0;
-   else if(b->b.y >= b->mxlines) b->b.y = b->mxlines - 1;
-   return(b->b.x = e_chr_sp(b->b.x, b, f));
+ extern struct mouse e_mouse;
+
+ b->b.x = e_mouse.x-f->a.x+s->c.x-1;
+ b->b.y = e_mouse.y-f->a.y+s->c.y-1;
+ if (b->b.y < 0) b->b.y = 0;
+ else if (b->b.y >= b->mxlines) b->b.y = b->mxlines - 1;
+ return(b->b.x = e_chr_sp(b->b.x, b, f));
 }
 
 /*  Copy, Cut and Paste functions    */
-
-int e_ccp_mouse(c, f)
-     int c;
-     FENSTER *f;
+int e_ccp_mouse(int c, FENSTER *f)
 {
-   BUFFER *b = f->ed->f[f->ed->mxedt]->b;
-   SCHIRM *s = f->ed->f[f->ed->mxedt]->s;
-   while(e_mshit() != 0);
-   if(c == -2)
-   {  e_mouse_cursor(b, s, f);
-      return((bioskey() & 8) ? AltEin : ShiftEin);
-   }
-   else if(c == -4)
-   {  return((bioskey() & 3) ? ShiftDel :
-		((bioskey() & 8) ? AltDel : CEINFG));
-   }
-   else return(0);
+ BUFFER *b = f->ed->f[f->ed->mxedt]->b;
+ SCHIRM *s = f->ed->f[f->ed->mxedt]->s;
+
+ while (e_mshit() != 0)
+  ;
+ if (c == -2)
+ {
+  e_mouse_cursor(b, s, f);
+  return((bioskey() & 8) ? AltEin : ShiftEin);
+ }
+ else if (c == -4)
+ {
+  return((bioskey() & 3) ? ShiftDel : ((bioskey() & 8) ? AltDel : CEINFG));
+ }
+ else return(0);
 }
 
-/*       Maus-Cursor-in-Edit-Fenster-Steuerung   */
+/*       Mouse cursor in edit window control   */
 void e_cur_mouse(f)
      FENSTER *f;
 {
@@ -816,7 +830,7 @@ void e_cur_mouse(f)
    bs.x = b->b.x;  bs.y = b->b.y;
    e_mouse_cursor(b, s, f);
    if((bioskey() & 3) == 0)
-   {  if(b->b.x == bs.x && b->b.y == bs.y && f->dtmd != 'h')
+   {  if(b->b.x == bs.x && b->b.y == bs.y && f->dtmd != DTMD_HELP)
       {  if(s->mark_begin.y == b->b.y && s->mark_end.y == b->b.y
 		&& s->mark_begin.x <= b->b.x && s->mark_end.x > b->b.x)
 	 {  s->mark_begin.x = 0;  s->mark_end.x = b->bf[b->b.y].len;  }
@@ -1093,20 +1107,25 @@ void e_opt_eck_mouse(o)
    e_std_rahmen(o->xa, o->ya, o->xe, o->ye, o->name, 1, o->frt, o->frs);
 }
 
-int e_opt_mouse(o)
-     W_OPTSTR *o;
+int e_opt_mouse(W_OPTSTR *o)
 {
-   extern struct mouse e_mouse;
-   int c;
-   if(e_mouse.y < o->ya || e_mouse.y >= o->ye ||
-	e_mouse.x <= o->xa || e_mouse.x >= o->xe) return(-1);
-   else if(e_mouse.y == o->ya)
-   {  if(e_mouse.x == o->xa+3) {  while(e_mshit());  return(WPE_ESC);  }
-      else {  e_opt_eck_mouse(o);  return(-1);  }
-   }
-   while(e_mshit());
-   if((c = e_get_opt_sw(0, e_mouse.x, e_mouse.y, o))) return(c);
-   else return(-1);
+ extern struct mouse e_mouse;
+ int c;
+
+ if (e_mouse.y < o->ya || e_mouse.y >= o->ye ||
+   e_mouse.x <= o->xa || e_mouse.x >= o->xe)
+  return(-1);
+ else if (e_mouse.y == o->ya)
+ {
+  if (e_mouse.x == o->xa+3)
+  {  while(e_mshit());  return(WPE_ESC);  }
+  else
+  {  e_opt_eck_mouse(o);  return(-1);  }
+ }
+ while (e_mshit())
+  ;
+ if ((c = e_get_opt_sw(0, e_mouse.x, e_mouse.y, o))) return(c);
+ else return(-1);
 }
 
 #endif
