@@ -28,7 +28,6 @@ extern char *info_file;
 extern int e_deb_type;
 #endif
 extern FARBE *u_fb, *x_fb;
-#define MAGIC 134
 
 #define OPTION_SECTIONS 4
 #define OPT_SECTION_GENERAL     "General"
@@ -583,9 +582,10 @@ int e_opt_save(FENSTER *f)
  return(ret);
 }
 
-char *WpeStringToValue(char *str)
+char *WpeStringToValue(const char *str)
 {
- char *answer, *cur_ans, *cur_str;
+ char *answer, *cur_ans;
+ const char *cur_str;
  int i, len;
 
  len = strlen(str);
@@ -607,9 +607,10 @@ char *WpeStringToValue(char *str)
  return answer;
 }
 
-char *WpeValueToString(char *value)
+char *WpeValueToString(const char *value)
 {
- char *answer, *cur_ans, *cur_val;
+ char *answer, *cur_ans;
+ const char *cur_val;
  int i;
 
  answer = WpeMalloc((strlen(value) + 1) * sizeof(char));
@@ -652,6 +653,10 @@ int WpeReadGeneral(ECNT *cn, char *section, char *option, char *value)
   cn->autoindent = atoi(value);
  else if (WpeStrccmp("PrintCmd", option) == 0)
   cn->print_cmd = WpeStrdup(value);
+ else if (WpeStrccmp("Version", option) == 0)
+ {
+  sscanf(value, "%d.%d.%d", &cn->major, &cn->minor, &cn->patch);
+ }
  return 0;
 }
 
@@ -676,18 +681,27 @@ int WpeReadColor(ECNT *cn, char *section, char *option, char *value)
 {
  FARBE *fb = NULL;
  COLOR *c = NULL;
+ int convert = 0; /* Convert old X11 colors to new colors */
 
  if (WpeStrccmp("Term", section + strlen(OPT_SECTION_COLOR) + 1) == 0)
  {
   if (!u_fb)
+  {
    u_fb = WpeMalloc(sizeof(FARBE));
+   FARBE_Init(u_fb);
+  }
   fb = u_fb;
  }
  if (WpeStrccmp("X11", section + strlen(OPT_SECTION_COLOR) + 1) == 0)
  {
   if (!x_fb)
+  {
    x_fb = WpeMalloc(sizeof(FARBE));
+   FARBE_Init(x_fb);
+  }
   fb = x_fb;
+  if ((cn->major <= 1) && (cn->minor <= 5) && (cn->patch <= 27))
+   convert = 1;
  }
  if (WpeStrccmp("er", option) == 0)
   c = &fb->er;
@@ -770,6 +784,33 @@ int WpeReadColor(ECNT *cn, char *section, char *option, char *value)
  if (c != NULL)
  {
   sscanf(value, "%d%d", &c->f, &c->b);
+  if (convert)
+  {
+   switch (c->f)
+   {
+    case 1: c->f = 4; break;
+    case 3: c->f = 6; break;
+    case 4: c->f = 1; break;
+    case 6: c->f = 3; break;
+    case 9: c->f = 12; break;
+    case 11: c->f = 14; break;
+    case 12: c->f = 9; break;
+    case 14: c->f = 11; break;
+    default: break;
+   }
+   switch (c->b)
+   {
+    case 1: c->b = 4; break;
+    case 3: c->b = 6; break;
+    case 4: c->b = 1; break;
+    case 6: c->b = 3; break;
+    case 9: c->b = 12; break;
+    case 11: c->b = 14; break;
+    case 12: c->b = 9; break;
+    case 14: c->b = 11; break;
+    default: break;
+   }
+  }
   *c = e_s_clr(c->f, c->b);
  }
  return 0;
