@@ -2761,6 +2761,8 @@ int e_p_mess_win(char *header, int argc, char **argv, PIC **pic, FENSTER *f)
  return(ret);
 }
 
+/* After this function b has exactly 1 line allocated (b->mxlines==1).
+   This line is initialized to the string WPE_WR,0 */
 int e_p_red_buffer(BUFFER *b)
 {
  int i;
@@ -2768,6 +2770,7 @@ int e_p_red_buffer(BUFFER *b)
  for (i = 1; i < b->mxlines; i++)
   if (b->bf[i].s != NULL)
    FREE( b->bf[i].s );
+ if (b->mxlines==0) e_new_line(0,b);
  b->bf[0].s[0] = WPE_WR;
  b->bf[0].s[1] = '\0';
  b->bf[0].len = 0;
