@@ -48,7 +48,9 @@ extern int MAXSLNS;
 extern int MAXSCOL;
 
 
+#ifndef NCURSES
 char *key_f[KEYFN], *key_key;
+#endif
 char *cur_rc, *cur_vs, *cur_nvs, *cur_vvs, cur_attr;
 char *att_so, *att_ul, *att_rv, *att_bl, *att_dm, *att_bo;
 char *ratt_no, *ratt_so, *ratt_ul, *ratt_rv, *ratt_bl, *ratt_dm, *ratt_bo;
@@ -58,7 +60,11 @@ extern char *att_no;
 char *col_fg, *col_bg, *spc_st, *spc_in, *spc_bg, *spc_nd;
 
 extern int col_num;
+#ifdef NCURSES
+chtype sp_chr[NSPCHR];
+#else
 char *sp_chr[NSPCHR];
+#endif
 
 extern int cur_x, cur_y;
 extern struct termios otermio, ntermio, ttermio;
@@ -71,6 +77,9 @@ char *tgetstr();
 int tgetnum();
 char *tgoto();
 #define tigetstr(k) tgetstr(k, &ap)
+
+#define term_move(x,y) e_putp(tgoto(cur_rc, x, y))
+#define term_refresh() fflush(stdout)
 #else
 /* Because term.h defines "buttons" it messes up we_gpm.c if in edit.h */
 #include <term.h>
@@ -78,6 +87,14 @@ char *tgoto();
 /* AIX requires that tparm has 10 arguments. */
 #define tparm1(a,b) tparm((a), (b), 0, 0, 0, 0, 0, 0, 0, 0)
 #define tparm2(a,b,c) tparm((a), (b), (c), 0, 0, 0, 0, 0, 0, 0)
+
+#ifdef NCURSES
+#define term_move(x,y) move(y, x)
+#define term_refresh() refresh()
+#else
+#define term_move(x,y) e_putp(tparm2(cur_rc, y, x))
+#define term_refresh() fflush(stdout)
+#endif
 #endif
 
 int WpeDllInit(int *argc, char **argv)
@@ -186,6 +203,7 @@ char *init_key(char *key)
  return(keystr);
 }
 
+#ifndef NCURSES
 char *init_kkey(char *key)
 {
  char *tmp;
@@ -212,6 +230,7 @@ char *init_kkey(char *key)
  }
  return(tmp);
 }
+#endif
 
 char *init_spchr(char c)
 {
@@ -234,8 +253,6 @@ char *init_spchr(char c)
 int init_cursor()
 {
 #ifndef TERMCAP
-   WINDOW * stdscr;
-
    if (!(cur_rc = init_key("cup")))
     return(-1);
    if ((col_fg = init_key("setaf")) && (col_bg = init_key("setab")))
@@ -252,9 +269,6 @@ int init_cursor()
     if(col_bg) {  free(col_bg);  col_bg = NULL;   }
    }
 
-   if ((stdscr=initscr())==(WINDOW *)ERR) exit(27);
-
-   start_color();
    spc_st = init_key("acsc");
    spc_in = init_key("enacs");
    spc_bg = init_key("smacs");
@@ -278,6 +292,7 @@ int init_cursor()
    sav_cur = init_key("sc");
    res_cur = init_key("rc");
 
+#ifndef NCURSES
    key_f[0] = init_kkey("kf1");
    key_f[1] = init_kkey("kf2");
    key_f[2] = init_kkey("kf3");
@@ -320,6 +335,7 @@ int init_cursor()
    key_f[39] = init_kkey("kEND");
    key_f[40] = init_kkey("kind");
    key_f[41] = init_kkey("kext");
+#endif
 
 #else
 
@@ -352,7 +368,17 @@ int init_cursor()
    swt_scr = init_key("te");
    sav_cur = init_key("sc");
    res_cur = init_key("rc");
-   
+
+   key_f[0] = init_kkey("k1");
+   key_f[1] = init_kkey("k2");
+   key_f[2] = init_kkey("k3");
+   key_f[3] = init_kkey("k4");
+   key_f[4] = init_kkey("k5");
+   key_f[5] = init_kkey("k6");
+   key_f[6] = init_kkey("k7");
+   key_f[7] = init_kkey("k8");
+   key_f[8] = init_kkey("k9");
+   key_f[9] = init_kkey("k;");
    key_f[10] = init_kkey("ku");
    key_f[11] = init_kkey("kd");
    key_f[12] = init_kkey("kl");
@@ -366,16 +392,6 @@ int init_cursor()
    key_f[20] = init_kkey("kb");
    key_f[21] = init_kkey("%1");
    key_f[22] = init_kkey("kH");
-   key_f[0] = init_kkey("k1");
-   key_f[1] = init_kkey("k2");
-   key_f[2] = init_kkey("k3");
-   key_f[3] = init_kkey("k4");
-   key_f[4] = init_kkey("k5");
-   key_f[5] = init_kkey("k6");
-   key_f[6] = init_kkey("k7");
-   key_f[7] = init_kkey("k8");
-   key_f[8] = init_kkey("k9");
-   key_f[9] = init_kkey("k;");
    key_f[23] = init_kkey("F7");
    key_f[24] = init_kkey("F8");
    key_f[25] = init_kkey("F9");
@@ -396,6 +412,21 @@ int init_cursor()
    key_f[40] = init_kkey("kF");
    key_f[41] = init_kkey("@1");
 #endif
+#ifdef NCURSES
+   sp_chr[0] = 0;
+   sp_chr[1] = ACS_ULCORNER;
+   sp_chr[2] = ACS_URCORNER;
+   sp_chr[3] = ACS_LLCORNER;
+   sp_chr[4] = ACS_LRCORNER;
+   sp_chr[5] = ACS_HLINE;
+   sp_chr[6] = ACS_VLINE;
+   sp_chr[7] = ACS_S9;
+   sp_chr[8] = ACS_VLINE;
+   sp_chr[9] = ACS_VLINE;
+   sp_chr[10] = ACS_S9;
+   sp_chr[11] = ACS_DIAMOND;
+   sp_chr[12] = ' ';
+#else
    sp_chr[0] = "";
    if(!(sp_chr[1] = init_spchr('l'))) sp_chr[1] = "+";
    if(!(sp_chr[2] = init_spchr('k'))) sp_chr[2] = "+";
@@ -409,50 +440,79 @@ int init_cursor()
    if(!(sp_chr[10] = init_spchr('q'))) sp_chr[10] = "_";
    if(!(sp_chr[11] = init_spchr('`'))) sp_chr[11] = "#";
    if(!(sp_chr[12] = init_spchr('a'))) sp_chr[12] = " ";
+#endif
    return(0);
 }
 
 int e_t_initscr()
-{  int ret;
-   ret = tcgetattr(1, &otermio); /* save old settings */
-/*   ret = ioctl(1, TCGETA, &otermio);     / save old settings */
+{
+ int ret, i, k;
+#ifndef TERMCAP
+ WINDOW * stdscr;
+#endif
+
+ ret = tcgetattr(1, &otermio); /* save old settings */
 /*
-    if(ret)
-    {	printf("Error in Terminal Initialisation Code: %d\n", ret);
-    	printf("c_iflag = %o, c_oflag = %o, c_cflag = %o,\n",
-		otermio.c_iflag, otermio.c_oflag, otermio.c_cflag);
-    	printf("c_lflag = %o, c_line = %o, c_cc = {\"\\%o\\%o\\%o\\%o\\%o\\%o\\%o\\%o\"}\n",
-		otermio.c_lflag, otermio.c_line, otermio.c_cc[0], otermio.c_cc[1], 
-		otermio.c_cc[2], otermio.c_cc[3], otermio.c_cc[4], otermio.c_cc[5], 
-		otermio.c_cc[6], otermio.c_cc[7]);
-        WpeExit(1);
-    }
+ if(ret)
+ {
+  printf("Error in Terminal Initialisation Code: %d\n", ret);
+  printf("c_iflag = %o, c_oflag = %o, c_cflag = %o,\n",
+    otermio.c_iflag, otermio.c_oflag, otermio.c_cflag);
+  printf("c_lflag = %o, c_line = %o, c_cc = {\"\\%o\\%o\\%o\\%o\\%o\\%o\\%o\\%o\"}\n",
+    otermio.c_lflag, otermio.c_line, otermio.c_cc[0], otermio.c_cc[1], 
+    otermio.c_cc[2], otermio.c_cc[3], otermio.c_cc[4], otermio.c_cc[5], 
+    otermio.c_cc[6], otermio.c_cc[7]);
+  WpeExit(1);
+ }
 */
-   e_begscr();
-   schirm = MALLOC(2 * MAXSCOL * MAXSLNS);
-   altschirm = MALLOC(2 * MAXSCOL * MAXSLNS);
-#if !defined(NO_XWINDOWS) && defined(NEWSTYLE)
-   extbyte = MALLOC(MAXSCOL * MAXSLNS);
+#ifndef TERMCAP
+ if ((stdscr=initscr())==(WINDOW *)ERR) exit(27);
+#ifdef NCURSES
+ cbreak();
+ noecho();
+ nonl();
+ intrflush(stdscr,FALSE);
+ keypad(stdscr,TRUE);
 #endif
-   e_abs_refr();
-   if(init_cursor())
-   {  printf("Terminal Not in the right mode\n");
-      e_exit(1);
+ if (has_colors())
+ {
+  start_color();
+  for (i = 0; i < COLORS; i++)
+  {
+   for (k = 0; k < COLORS; k++)
+   {
+    if (i != 0 || k != 0)
+    {
+     init_pair(i * 8 + k, k, i);
+    }
    }
-   tcgetattr(0, &ntermio);
-/*   ioctl(0, TCGETA, &ntermio);*/
-   ntermio.c_iflag = 0;            /* setup new settings */
-   ntermio.c_oflag = 0;
-   ntermio.c_lflag = 0;
-   ntermio.c_cc[VMIN] = 1;
-   ntermio.c_cc[VTIME] = 0;
-#ifdef VSWTCH
-   ntermio.c_cc[VSWTCH] = 0;
+  }
+ }
 #endif
-   tcsetattr(0, TCSADRAIN, &ntermio);
-/*   ioctl(0, TCSETA, &ntermio);*/
-   if(spc_in) e_putp(spc_in);
-   return(0);
+ e_begscr();
+ schirm = MALLOC(2 * MAXSCOL * MAXSLNS);
+ altschirm = MALLOC(2 * MAXSCOL * MAXSLNS);
+#if !defined(NO_XWINDOWS) && defined(NEWSTYLE)
+ extbyte = MALLOC(MAXSCOL * MAXSLNS);
+#endif
+ e_abs_refr();
+ if(init_cursor())
+ {
+  printf("Terminal Not in the right mode\n");
+  e_exit(1);
+ }
+ tcgetattr(0, &ntermio);
+ ntermio.c_iflag = 0;            /* setup new settings */
+ ntermio.c_oflag = 0;
+ ntermio.c_lflag = 0;
+ ntermio.c_cc[VMIN] = 1;
+ ntermio.c_cc[VTIME] = 0;
+#ifdef VSWTCH
+ ntermio.c_cc[VSWTCH] = 0;
+#endif
+ tcsetattr(0, TCSADRAIN, &ntermio);
+ if (spc_in) e_putp(spc_in);
+ return(0);
 }
 
 int svflgs, kbdflgs;
@@ -463,7 +523,9 @@ int e_begscr()
 
  kbdflgs = fcntl( 0, F_GETFL, 0 );
 #ifndef TERMCAP
+#ifndef NCURSES
  setupterm((char *)0, 1, (int *)0);
+#endif
  if ((lns = tigetnum("lines")) > 0)
   MAXSLNS = lns;
  if ((cols = tigetnum("cols")) > 0)
@@ -485,9 +547,12 @@ int e_begscr()
 
 void e_endwin()
 {
+#ifdef NCURSES
+ endwin();
+#else
  fk_putp(ratt_bo);
+#endif
  tcsetattr(0, TCSADRAIN, &otermio);
-/* ioctl(0, TCSETA, &otermio);*/
 }
 
 int fk_t_cursor(int x)
@@ -497,12 +562,28 @@ int fk_t_cursor(int x)
 
 int fk_t_putchar(int c)
 {
+#ifdef NCURSES
+ addch(c);
+ return c;
+#else
  return(fputc(c, stdout));
+#endif
 }
 
 int fk_attrset(int a)
 {
  if(cur_attr == a) return(0);
+#ifdef NCURSES
+ switch(a)
+ {  case 0:  attrset(A_NORMAL);  break;
+    case 1:  attrset(A_STANDOUT);  break;
+    case 2:  attrset(A_UNDERLINE);  break;
+    case 4:  attrset(A_REVERSE);  break;
+    case 8:  attrset(A_BLINK);  break;
+    case 16:  attrset(A_DIM);  break;
+    case 32:  attrset(A_BOLD);  break;
+ }
+#else
  switch(cur_attr)
  {  case 0:  fk_putp(ratt_no);  break;
     case 1:  fk_putp(ratt_so);  break;
@@ -521,6 +602,7 @@ int fk_attrset(int a)
     case 16:  fk_putp(att_dm);  break;
     case 32:  fk_putp(att_bo);  break;
  }
+#endif
  return(cur_attr = a);
 }
 
@@ -543,6 +625,13 @@ void fk_colset(int c)
   e_putp(tgoto(col_fg, 0, c));
   e_putp(tgoto(col_bg, 0, bg));
  }
+#else
+#ifdef NCURSES
+ if (c & 8)
+  attrset(A_BOLD);
+ else
+  attrset(A_NORMAL);
+ color_set((bg * 8) + c % 8, NULL);
 #else
  if ((c %= 16) >= col_num)
  {
@@ -557,44 +646,56 @@ void fk_colset(int c)
   e_putp(tparm1(col_bg, bg));
  }
 #endif
+#endif
 }
 
 int e_t_refresh()
 {
-   int x = cur_x, y = cur_y, i, j, c;
-   fk_cursor(0);
-   for(i = 0; i < MAXSLNS; i++)
-   for(j = 0; j < MAXSCOL; j++)
-   {  if(i == MAXSLNS-1 && j == MAXSCOL-1) break;
-      if(*(schirm + 2*MAXSCOL * i + 2 * j) != *(altschirm + 2*MAXSCOL * i + 2 * j) ||
-         *(schirm + 2*MAXSCOL * i + 2 * j + 1) != *(altschirm + 2*MAXSCOL * i + 2 * j + 1) )
-#ifndef TERMCAP
-      {  if(cur_x != j || cur_y != i) e_putp(tparm2(cur_rc, i, j));
+ int x = cur_x, y = cur_y, i, j, c;
+ fk_cursor(0);
+ for(i = 0; i < MAXSLNS; i++)
+  for(j = 0; j < MAXSCOL; j++)
+  {
+   if (i == MAXSLNS-1 && j == MAXSCOL-1) break;
+   if (*(schirm + 2*MAXSCOL * i + 2 * j) != *(altschirm + 2*MAXSCOL * i + 2 * j) ||
+     *(schirm + 2*MAXSCOL * i + 2 * j + 1) != *(altschirm + 2*MAXSCOL * i + 2 * j + 1) )
+   {
+    if (cur_x != j || cur_y != i)
+     term_move(j, i);
+    if (cur_x < MAXSCOL)
+    {  cur_x = j + 1;  cur_y = i;  }
+    else
+    {  cur_x = 0;  cur_y = i+1;  }
+    if (col_num <= 0)
+     fk_attrset(e_gt_col(j, i));
+    else
+     fk_colset(e_gt_col(j, i));
+    c = e_gt_char(j, i);
+#ifdef NCURSES
+    if (c < NSPCHR)
+     addch(sp_chr[c]);
+    else
+     addch(c);
 #else
-      {  if(cur_x != j || cur_y != i) e_putp(tgoto(cur_rc, j, i));
+    if (c < NSPCHR)
+     e_putp(sp_chr[c]);
+    else
+     fputc(c, stdout);
 #endif
-	 if(cur_x < MAXSCOL)
-	 {  cur_x = j + 1;  cur_y = i;  }
-	 else
-	 {  cur_x = 0;  cur_y = i+1;  }
-	 if(col_num <= 0) fk_attrset(e_gt_col(j, i));
-	 else fk_colset(e_gt_col(j, i));
-         if((c = e_gt_char(j, i)) < NSPCHR) e_putp(sp_chr[c]);
-         else fputc(e_gt_char(j, i), stdout);
-	 *(altschirm + 2*MAXSCOL * i + 2 * j) = *(schirm + 2*MAXSCOL * i + 2 * j);
-	 *(altschirm + 2*MAXSCOL * i + 2 * j + 1) = *(schirm + 2*MAXSCOL * i + 2 * j + 1);
-      }
+    *(altschirm + 2*MAXSCOL * i + 2 * j) = *(schirm + 2*MAXSCOL * i + 2 * j);
+    *(altschirm + 2*MAXSCOL * i + 2 * j + 1) = *(schirm + 2*MAXSCOL * i + 2 * j + 1);
    }
-   fk_cursor(1);
-   fk_locate(x, y);
-   return(0);
+  }
+ fk_cursor(1);
+ fk_locate(x, y);
+ term_refresh();
+ return(0);
 }
 
 int e_t_sys_ini()
 {
  e_refresh();
  tcgetattr(0, &ttermio);
-/* ioctl(0, TCGETA, &ttermio);*/
  svflgs = fcntl( 0, F_GETFL, 0 );
  e_endwin();
  return(0);   
@@ -603,7 +704,6 @@ int e_t_sys_ini()
 int e_t_sys_end()
 {
  tcsetattr(0, TCSADRAIN, &ttermio);
-/* ioctl(0, TCSETA, &ttermio);*/
  fcntl( 0, F_SETFL, svflgs );
  e_abs_refr();
  fk_locate(0, 0);
@@ -623,8 +723,117 @@ int e_t_kbhit()
  return (ret == 1 ? c : 0);
 }
 
-extern char *key_key, *key_f[];
+#ifdef NCURSES
+int e_t_getch()
+{
+ int c, bk;
 
+ e_refresh();
+ c = fk_getch();
+ if (c > KEY_CODE_YES)
+ {
+  switch (c)
+  {
+   case KEY_F(1):  c = F1; break;
+   case KEY_F(2):  c = F2; break;
+   case KEY_F(3):  c = F3; break;
+   case KEY_F(4):  c = F4; break;
+   case KEY_F(5):  c = F5; break;
+   case KEY_F(6):  c = F6; break;
+   case KEY_F(7):  c = F7; break;
+   case KEY_F(8):  c = F8; break;
+   case KEY_F(9):  c = F9; break;
+   case KEY_F(10):  c = F10; break;
+   case KEY_UP:  c = CUP; break;
+   case KEY_DOWN:  c = CDO; break;
+   case KEY_LEFT:  c = CLE; break;
+   case KEY_RIGHT:  c = CRI; break;
+   case KEY_SFIND:  c = EINFG; break;
+   case KEY_IC:  c = POS1; break;
+   case KEY_DC:  c = BUP; break;
+   case KEY_PPAGE:  c = ENDE; break;
+   case KEY_NPAGE:  c = BDO; break;
+   case KEY_BACKSPACE:  c = WPE_DC; break;
+   case KEY_HELP:  c = HELP; break;
+   case KEY_LL:  c = ENDE; break;
+   case KEY_F(17):  c = SF1; break;
+   case KEY_F(18):  c = SF2; break;
+   case KEY_F(19):  c = SF3; break;
+   case KEY_F(20):  c = SF4; break;
+   case KEY_F(21):  c = SF5; break;
+   case KEY_F(22):  c = SF6; break;
+   case KEY_F(23):  c = SF7; break;
+   case KEY_F(24):  c = SF8; break;
+   case KEY_F(25):  c = SF9; break;
+   case KEY_F(26):  c = SF10; break;
+   case KEY_PREVIOUS:  c = CUP+512; break;
+   case KEY_NEXT:  c = CDO+512; break;
+   case KEY_HOME:  c = POS1+512; break;
+   case KEY_END:  c = ENDE+512; break;
+   default:  c = 0; break;
+  }
+  bk = bioskey();
+  if (bk & 3)
+   c += 512;
+  else if (bk & 4)
+   c += 514;
+ }
+ else if ( c == WPE_TAB )
+ {
+  bk = bioskey(); 
+  if ( bk & 3)
+   c = WPE_BTAB;
+  else
+   c = WPE_TAB;
+ }
+ else if (c == WPE_ESC)
+ {
+  c = fk_getch();
+  if (c > KEY_CODE_YES)
+  {
+   switch (c)
+   {
+    case KEY_F(1):  c = AF1; break;
+    case KEY_F(2):  c = AF2; break;
+    case KEY_F(3):  c = AF3; break;
+    case KEY_F(4):  c = AF4; break;
+    case KEY_F(5):  c = AF5; break;
+    case KEY_F(6):  c = AF6; break;
+    case KEY_F(7):  c = AF7; break;
+    case KEY_F(8):  c = AF8; break;
+    case KEY_F(9):  c = AF9; break;
+    case KEY_F(10):  c = AF10; break;
+    case KEY_UP:  c = BUP; break;
+    case KEY_DOWN:  c = BDO; break;
+    case KEY_LEFT:  c = CCLE; break;
+    case KEY_RIGHT:  c = CCRI; break;
+    case KEY_SFIND:  c = EINFG; break;
+    case KEY_IC:  c = CPS1; break;
+    case KEY_DC:  c = CBUP; break;
+    case KEY_PPAGE:  c = CEND; break;
+    case KEY_NPAGE:  c = CBDO; break;
+    case KEY_BACKSPACE:  c = AltBS; break;
+    case KEY_HELP:  c = AF1; break;
+    case KEY_LL:  c = CEND; break;
+    case KEY_PREVIOUS:  c = BUP+512; break;
+    case KEY_NEXT:  c = BDO+512; break;
+    case KEY_HOME:  c = CPS1+512; break;
+    case KEY_END:  c = CEND+512; break;
+    default:  c = 0; break;
+   }
+   bk = bioskey();
+   if (bk & 3)
+    c += 512;
+   else if (bk & 4)
+    c += 514;
+  }
+  else if (c != WPE_ESC)
+   c = e_tast_sim(c);
+ }
+ return(c);
+}
+
+#else
 int e_t_getch()
 {
  int c, c2, pshift, bk;
@@ -638,12 +847,13 @@ int e_t_getch()
   else if (key_f[17] && c == *key_f[17])
    return(ENTF);
   else if ( c == WPE_TAB )
-   { bk = bioskey(); 
-     if ( bk & 3) 
-         return (WPE_BTAB); 
-	    else 
-	 return (WPE_TAB); 
-    }
+  {
+   bk = bioskey(); 
+   if (bk & 3) 
+    return (WPE_BTAB); 
+   else
+    return (WPE_TAB); 
+  }
   else
    return(c);
  }
@@ -766,22 +976,23 @@ int e_find_key(int c, int j, int sw)
    }
    return(0);
 }
+#endif
 
 int fk_t_locate(int x, int y)
 {
  if (col_num > 0) 
  {
   fk_colset(e_gt_col(cur_x, cur_y));
+#ifdef NCURSES
+  /* Causes problems.  Reason unknown. - Dennis */
+  /*mvaddch(cur_y,cur_x,e_gt_char(cur_x, cur_y));*/
+#else
   fputc(e_gt_char(cur_x, cur_y), stdout);
+#endif
  }
  cur_x = x;
  cur_y = y;
-#ifndef TERMCAP
- e_putp(tparm2(cur_rc, y, x));
-#else
- e_putp(tgoto(cur_rc, x, y));
-#endif
- fflush(stdout);
+ term_move(x, y);
  return(y);
 }
 
@@ -799,7 +1010,7 @@ int e_t_switch_screen(int sw)
  sav_sw = sw;
  if (sw && beg_scr) 
  {
-  fflush(stdout);
+  term_refresh();
   if (sav_cur)
    e_putp(sav_cur);
   e_putp(beg_scr);
@@ -809,7 +1020,7 @@ int e_t_switch_screen(int sw)
   e_putp(swt_scr);
   if (res_cur)
    e_putp(res_cur);
-  fflush(stdout);
+  term_refresh();
  }
  else
   return(-1);
@@ -818,7 +1029,9 @@ int e_t_switch_screen(int sw)
 
 int e_t_deb_out(FENSTER *f)
 {
+#ifndef NCURSES
  if (!swt_scr || !beg_scr)
+#endif
   return(e_error("Your terminal don\'t use begin/end cup", 0, f->fb));
  e_d_switch_out(1);
  getchar();
@@ -847,21 +1060,13 @@ int e_t_d_switch_out(int sw)
  save_sw = sw;
  if (sw && e_d_switch_screen(0))
  {
-#ifndef TERMCAP
-  e_putp(tparm2(cur_rc, 0, 0));
-#else
-  e_putp(tgoto(cur_rc, 0, 0));
-#endif
+  term_move(0, 0);
   e_putp(att_no);
   for(i = 0; i < MAXSLNS; i++)
    for (j = 0; j < MAXSCOL; j++)
     e_d_putchar(' ');
-#ifndef TERMCAP
-  e_putp(tparm2(cur_rc, 0, 0));
-#else
-  e_putp(tgoto(cur_rc, 0, 0));
-#endif
-  fflush(stdout);
+  term_move(0, 0);
+  term_refresh();
  }
  else if (!sw)
  {
