@@ -13,14 +13,13 @@ int WpeXtermInit(int *argc, char **argv);
 int WpeTermInit(int *argc, char **argv);
 #endif
 
-#ifdef UNIX
-
 #include <termios.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <sys/wait.h>
 #include <dirent.h>
 #include <signal.h>
+#include <locale.h>
 #ifndef TERMCAP
 #ifndef DJGPP
 #include<curses.h>
@@ -60,7 +59,7 @@ int (*e_u_refresh)(void);
 int (*e_u_getch)(void);
 int (*e_u_sys_ini)(void);
 int (*e_u_sys_end)(void);
-int (*e_u_system)(char *exe);
+int (*e_u_system)(const char *exe);
 int (*e_make_urect)(int xa, int ya, int xe, int ye, int sw);
 int (*e_make_urect_abs)(int xa, int ya, int xe, int ye, int sw);
 int (*e_u_d_switch_out)(int sw);
@@ -111,12 +110,21 @@ int WpeZeroFunction(void)
 int e_ini_unix(int *argc, char **argv)
 {
  extern OPT opt[];
- int i;
+ int i, debug;
  struct sigaction act;
  int (*initfunc)(int *argc, char **argv);
 
- u_fb = MALLOC(sizeof(FARBE));
- x_fb = MALLOC(sizeof(FARBE));
+ setlocale(LC_ALL, "");
+ u_fb = NULL;
+ x_fb = NULL;
+ debug = 0;
+ for (i = 1; i < *argc; i++)
+ {
+  if (strcmp("--debug", argv[i]) == 0)
+  {
+   debug = 1;
+  }
+ }
  for (i = strlen(argv[0])-1; i >= 0 && *(argv[0] + i) != DIRC; i--)
   ;
 #ifndef NO_XWINDOWS
@@ -159,8 +167,8 @@ int e_ini_unix(int *argc, char **argv)
  {
   WpeXtermInit(argc, argv);
  }
-#endif
  else
+#endif
  {
   WpeTermInit(argc, argv);
  }
@@ -168,7 +176,6 @@ int e_ini_unix(int *argc, char **argv)
  if (WpeIsProg())
  {
 #ifndef DEBUGGER
- {
   opt[0].x = 2, opt[1].x = 7, opt[2].x = 14; opt[3].x = 21; opt[4].x = 30;
   opt[9].t = opt[7].t; opt[9].x = 74; opt[9].s = opt[7].s; opt[9].as = opt[7].as;
   opt[8].t = opt[6].t; opt[8].x = 65; opt[8].s = opt[6].s; opt[8].as = opt[6].as;
@@ -194,20 +201,23 @@ int e_ini_unix(int *argc, char **argv)
  act.sa_handler = WpeSignalUnknown;
  sigfillset(&act.sa_mask); /* Mask all signals while running */
  act.sa_flags = 0;
- sigaction(SIGQUIT, &act, NULL);
- sigaction(SIGILL, &act, NULL);
- sigaction(SIGABRT, &act, NULL);
- sigaction(SIGFPE, &act, NULL);
- sigaction(SIGSEGV, &act, NULL);
+ if (!debug)
+ {
+  sigaction(SIGQUIT, &act, NULL);
+  sigaction(SIGILL, &act, NULL);
+  sigaction(SIGABRT, &act, NULL);
+  sigaction(SIGFPE, &act, NULL);
+  sigaction(SIGSEGV, &act, NULL);
 #ifdef SIGTRAP
- sigaction(SIGTRAP, &act, NULL);
+  sigaction(SIGTRAP, &act, NULL);
 #endif
 #ifdef SIGIOT
- sigaction(SIGIOT, &act, NULL);
+  sigaction(SIGIOT, &act, NULL);
 #endif
 #ifdef SIGBUS
- sigaction(SIGBUS, &act, NULL);
+  sigaction(SIGBUS, &act, NULL);
 #endif
+ }
  /* Ignore SIGINT */
  act.sa_handler = SIG_IGN;
  sigaction(SIGINT, &act, NULL);
@@ -326,8 +336,7 @@ static int e_bool_exit = 0;
 
 void e_err_save()
 {
- extern struct EXT h_error;
- ECNT *cn = h_error.cn;
+ ECNT *cn = WpeEditor;
  int i;
  long maxname;
  FENSTER *f;
@@ -337,9 +346,9 @@ void e_err_save()
  if (e_bool_exit)
   return ;
  e_bool_exit = 1;
- for(i = 0; i <= cn->mxedt; i++)
+ for (i = 0; i <= cn->mxedt; i++)
  {
-  if(cn->f[i]->dtmd > 'Z')
+  if (DTMD_ISTEXT(cn->f[i]->dtmd))
   {
    f = cn->f[i];
    b = cn->f[i]->b;
@@ -474,152 +483,174 @@ int e_compstr(char *a, char *b)
 
 struct dirfile *e_find_files(char *sufile, int sw)
 {
-  char            stmp[256], *tmpst, *sfile, *sdir;
-  struct dirfile *df = MALLOC(sizeof(struct dirfile));
-  DIR            *dirp;
-  struct dirent  *dp;
-  struct stat     buf;
-  struct stat     lbuf;
-  int             i, n, cexist;
-
-  df->name = NULL;
-  df->anz = 0;
-  for(n = strlen(sufile); n >= 0 && sufile[n] != DIRC; n--);
-  sfile = sufile + 1 + n;
-  if(n <= 0)
-  {
-    sdir = MALLOC(2 * sizeof(char));
-    sdir[0] = n ? '.' : DIRC;
-    sdir[1] = '\0';
-  }
-  else
-  {
-    sdir = MALLOC((n + 1) * sizeof(char));
-    for(i = 0; i < n; i++)
-      sdir[i] = sufile[i];
-    sdir[n] = '\0';
-  }
-  if(!(dirp = opendir(sdir)))
-  {
-    FREE(sdir);
-    return(df);
-  }
-  while((dp = readdir(dirp)) != NULL)
-  {
-    if(!(sw & 1) && dp->d_name[0] == '.' && sfile[0] != '.')
-      continue;
-    if(!e_compstr(sfile, dp->d_name))
-    {
-
-      e_mkfilepath(sdir, dp->d_name, stmp);
-      lstat(stmp, &lbuf);
-      stat(stmp, &buf);
-
-      /* check existence of the file */
-      cexist = access(stmp, F_OK);
-
-      /* we accept it as a file if
-         - a regular file
-         - link and it does not point to anything
-         - link and it points to a non-directory */
-      if(   (   S_ISREG(buf.st_mode) 
-             || (   S_ISLNK(lbuf.st_mode) 
-                 && (cexist || (cexist == 0 && !S_ISDIR(buf.st_mode))) ) )
-         && (!(sw & 2) || (buf.st_mode & 0111)) )
-      {
-        if(df->anz == 0)
-          df->name = MALLOC((df->anz + 1) * sizeof(char *));
-        else
-          df->name = REALLOC(df->name, (df->anz + 1) * sizeof(char *));
-        if(df->name == NULL || !(tmpst = MALLOC(strlen(dp->d_name) + 1)))
-        {
-          df->anz = 0;
-          closedir(dirp);
-          FREE(sdir);
-          return(df);
-        }
-        strcpy(tmpst, dp->d_name);
-        for(n = df->anz; n > 0 && strcmp(*(df->name + n - 1), tmpst) > 0; n--)
-          *(df->name + n) = *(df->name + n - 1);
-        *(df->name + n) = tmpst;
-        (df->anz)++;
-      }
-    }
-  }
-  closedir(dirp);
+ char           *stmp, *tmpst, *sfile, *sdir;
+ struct dirfile *df = MALLOC(sizeof(struct dirfile));
+ DIR            *dirp;
+ struct dirent  *dp;
+ struct stat     buf;
+ struct stat     lbuf;
+ int             i, n, cexist, sizeStmp, sizeSdir;
 
+ df->name = NULL;
+ df->anz = 0;
+ for (n = strlen(sufile); n >= 0 && sufile[n] != DIRC; n--);
+ sfile = sufile + 1 + n;
+ if (n <= 0)
+ {
+  sizeSdir = 2;
+  sdir = (char *)WpeMalloc(2 * sizeof(char));
+  sdir[0] = n ? '.' : DIRC;
+  sdir[1] = '\0';
+ }
+ else
+ {
+  sizeSdir = n + 1;
+  sdir = (char *)WpeMalloc((n + 1) * sizeof(char));
+  for (i = 0; i < n; i++)
+   sdir[i] = sufile[i];
+  sdir[n] = '\0';
+ }
+ if (!(dirp = opendir(sdir)))
+ {
   FREE(sdir);
   return(df);
+ }
+ sizeStmp = 256;
+ stmp = (char *)WpeMalloc(sizeStmp);
+ while((dp = readdir(dirp)) != NULL)
+ {
+  if (!(sw & 1) && dp->d_name[0] == '.' && sfile[0] != '.')
+   continue;
+  if (!e_compstr(sfile, dp->d_name))
+  {
+   if (sizeSdir + strlen(dp->d_name) + 10 > sizeStmp)
+   {
+    while (sizeSdir + strlen(dp->d_name) + 10 > sizeStmp)
+     sizeStmp <<= 1;
+    stmp = (char *)WpeRealloc(stmp, sizeStmp);
+   }
+
+   e_mkfilepath(sdir, dp->d_name, stmp);
+   lstat(stmp, &lbuf);
+   stat(stmp, &buf);
+
+   /* check existence of the file */
+   cexist = access(stmp, F_OK);
+
+   /* we accept it as a file if
+      - a regular file
+      - link and it does not point to anything
+      - link and it points to a non-directory */
+   if ((S_ISREG(buf.st_mode) ||
+     (S_ISLNK(lbuf.st_mode) &&
+     (cexist || (cexist == 0 && !S_ISDIR(buf.st_mode))))) &&
+     (!(sw & 2) || (buf.st_mode & 0111)) )
+   {
+    if (df->anz == 0)
+     df->name = MALLOC((df->anz + 1) * sizeof(char *));
+    else
+     df->name = REALLOC(df->name, (df->anz + 1) * sizeof(char *));
+    if (df->name == NULL || !(tmpst = MALLOC(strlen(dp->d_name) + 1)))
+    {
+     df->anz = 0;
+     closedir(dirp);
+     WpeFree(stmp);
+     WpeFree(sdir);
+     return(df);
+    }
+    strcpy(tmpst, dp->d_name);
+    for (n = df->anz; n > 0 && strcmp(*(df->name + n - 1), tmpst) > 0; n--)
+     *(df->name + n) = *(df->name + n - 1);
+    *(df->name + n) = tmpst;
+    (df->anz)++;
+   }
+  }
+ }
+ closedir(dirp);
+ WpeFree(stmp);
+ WpeFree(sdir);
+ return(df);
 }
 
 struct dirfile *e_find_dir(char *sufile, int sw)
 {
-  char            stmp[256], *tmpst, *sfile, *sdir;
-  struct dirfile *df = MALLOC(sizeof(struct dirfile));
-  DIR            *dirp;
-  struct dirent  *dp;
-  struct stat     buf;
-  int             i, n;
-
-  df->name = NULL;
-  df->anz = 0;
-  for(n = strlen(sufile); n >= 0 && sufile[n] != DIRC; n--);
-  sfile = sufile + 1;
-  sfile = sfile + n;
-  if(n <= 0)
-  {
-    sdir = MALLOC(2 * sizeof(char));
-    sdir[0] = n ? '.' : DIRC;
-    sdir[1] = '\0';
-  }
-  else
-  {
-    sdir = MALLOC((n + 1) * sizeof(char));
-    for(i = 0; i < n; i++)
-      sdir[i] = sufile[i];
-    sdir[n] = '\0';
-  }
-  if(!(dirp = opendir(sdir)))
-  {
-    FREE(sdir);
-    return(df);
-  }
-  while((dp = readdir(dirp)) != NULL)
-  {
-    if(!sw && dp->d_name[0] == '.' && sfile[0] != '.')
-      continue;
-    if(!e_compstr(sfile, dp->d_name) && strcmp(dp->d_name, ".")
-       && strcmp(dp->d_name, ".."))
-    {
-      stat(e_mkfilepath(sdir, dp->d_name, stmp), &buf);
-
-      /* we accept _only_ real, existing directories */
-      if(S_ISDIR(buf.st_mode))
-      {
-
-        if(df->anz == 0)
-          df->name = MALLOC((df->anz + 1) * sizeof(char *));
-        else
-          df->name = REALLOC(df->name, (df->anz + 1) * sizeof(char *));
-        if(df->name == NULL || !(tmpst = MALLOC(strlen(dp->d_name) + 1)))
-        {
-          df->anz = 0;
-          closedir(dirp);
-          FREE(sdir);
-          return(df);
-        }
-        strcpy(tmpst, dp->d_name);
-        for(n = df->anz; n > 0 && strcmp(*(df->name + n - 1), tmpst) > 0; n--)
-          *(df->name + n) = *(df->name + n - 1);
-        *(df->name + n) = tmpst;
-        (df->anz)++;
-      }
-    }
-  }
-  closedir(dirp);
+ char           *stmp, *tmpst, *sfile, *sdir;
+ struct dirfile *df = MALLOC(sizeof(struct dirfile));
+ DIR            *dirp;
+ struct dirent  *dp;
+ struct stat     buf;
+ int             i, n, sizeStmp, sizeSdir;
 
+ df->name = NULL;
+ df->anz = 0;
+ for (n = strlen(sufile); n >= 0 && sufile[n] != DIRC; n--);
+ sfile = sufile + 1;
+ sfile = sfile + n;
+ if (n <= 0)
+ {
+  sizeSdir = 2;
+  sdir = MALLOC(2 * sizeof(char));
+  sdir[0] = n ? '.' : DIRC;
+  sdir[1] = '\0';
+ }
+ else
+ {
+  sizeSdir = n + 1;
+  sdir = MALLOC((n + 1) * sizeof(char));
+  for (i = 0; i < n; i++)
+   sdir[i] = sufile[i];
+  sdir[n] = '\0';
+ }
+ if (!(dirp = opendir(sdir)))
+ {
   FREE(sdir);
   return(df);
+ }
+ sizeStmp = 256;
+ stmp = (char *)WpeMalloc(sizeStmp);
+ while ((dp = readdir(dirp)) != NULL)
+ {
+  if (!sw && dp->d_name[0] == '.' && sfile[0] != '.')
+   continue;
+  if (!e_compstr(sfile, dp->d_name) && strcmp(dp->d_name, ".") &&
+    strcmp(dp->d_name, ".."))
+  {
+   if (sizeSdir + strlen(dp->d_name) + 10 > sizeStmp)
+   {
+    while (sizeSdir + strlen(dp->d_name) + 10 > sizeStmp)
+     sizeStmp <<= 1;
+    stmp = (char *)WpeRealloc(stmp, sizeStmp);
+   }
+   stat(e_mkfilepath(sdir, dp->d_name, stmp), &buf);
+
+   /* we accept _only_ real, existing directories */
+   if (S_ISDIR(buf.st_mode))
+   {
+
+    if (df->anz == 0)
+     df->name = MALLOC((df->anz + 1) * sizeof(char *));
+    else
+     df->name = REALLOC(df->name, (df->anz + 1) * sizeof(char *));
+    if (df->name == NULL || !(tmpst = MALLOC(strlen(dp->d_name) + 1)))
+    {
+     df->anz = 0;
+     closedir(dirp);
+     FREE(sdir);
+     WpeFree(stmp);
+     return(df);
+    }
+    strcpy(tmpst, dp->d_name);
+    for (n = df->anz; n > 0 && strcmp(*(df->name + n - 1), tmpst) > 0; n--)
+     *(df->name + n) = *(df->name + n - 1);
+    *(df->name + n) = tmpst;
+    (df->anz)++;
+   }
+  }
+ }
+ closedir(dirp);
+ FREE(sdir);
+ WpeFree(stmp);
+ return(df);
 }
 
 #include <time.h>
@@ -631,7 +662,7 @@ char *e_file_info(char *filen, char *str, int *num, int sw)
 
  stat(filen, buf);
  ttm = localtime(&(buf->st_mtime));
- sprintf(str, "%c%c%c%c%c%c%c%c%c%c  %-13s  %6ld  %2.2u.%2.2u.%2.2u  %2.2u.%2.2u",
+ sprintf(str, "%c%c%c%c%c%c%c%c%c%c  %-13s  %6ld  %2.2u.%2.2u.%4.4u  %2.2u.%2.2u",
    buf->st_mode & 040000 ? 'd' : '-',
    buf->st_mode & 0400 ? 'r' : '-',
    buf->st_mode & 0200 ? 'w' : '-',
@@ -644,7 +675,7 @@ char *e_file_info(char *filen, char *str, int *num, int sw)
    buf->st_mode & 01 ? 'x' : '-',
    filen,
    buf->st_size, ttm->tm_mday,
-   ttm->tm_mon + 1, ttm->tm_year, ttm->tm_hour, ttm->tm_min);
+   ttm->tm_mon + 1, ttm->tm_year + 1900, ttm->tm_hour, ttm->tm_min);
  if (sw & 1) *num = buf->st_mtime;
  else if (sw & 2) *num = buf->st_size;
  return(str);
@@ -755,5 +786,3 @@ void e_pr_t_col_kasten(int xa, int ya, int x, int y, FENSTER * f, int sw)
  fk_locate(xa+4, ya + y + 1);
 }
 
-#endif
-
