@@ -94,8 +94,10 @@ int WpeDllInit(int *argc, char **argv)
  e_u_change = e_x_change;
  e_u_ini_size = e_ini_size;
  e_u_setlastpic = e_setlastpic;
- WpeMouseChangeShape = WpeXMouseChangeShape;
- WpeMouseRestoreShape = WpeXMouseRestoreShape;
+ WpeMouseChangeShape = (void (*)(WpeMouseShape))WpeNullFunction;
+ WpeMouseRestoreShape = (void (*)(WpeMouseShape))WpeNullFunction;
+/* WpeMouseChangeShape = WpeXMouseChangeShape;
+ WpeMouseRestoreShape = WpeXMouseRestoreShape;*/
  WpeDisplayEnd = WpeNullFunction;
  e_u_switch_screen = WpeZeroFunction;
  e_u_d_switch_out = (int (*)(int sw))WpeZeroFunction;
@@ -175,6 +177,34 @@ int nseg[8] = { 0, 0, 0, 0, 0, 0, 0, 0 };
 XSegment seg[8][WPE_MAXSEG];
 int scol[8] = { 0, 0, 15, 15, 15, 15, 0, 0 };
 
+int e_XLookupString(XKeyEvent *event, char *buffer_return, int buffer_size,
+		    KeySym *keysym_return, XComposeStatus *status)
+{
+    static int first = 1;
+    static XIC xic;
+    static XIM xim;
+
+    if (first) {
+	if (!XSetLocaleModifiers(""))
+	    XSetLocaleModifiers("@im=none");
+	xim = XOpenIM(event->display, NULL, NULL, NULL);
+	xic = XCreateIC(xim,
+			XNInputStyle, XIMPreeditNothing | XIMStatusNothing,
+			XNClientWindow, WpeXInfo.window, NULL);
+	first = 0;
+    }
+    if (xic) {
+	if (XFilterEvent((XEvent*)event, WpeXInfo.window))
+	    return (0);
+
+	return (XmbLookupString(xic, event, buffer_return, buffer_size,
+				keysym_return, NULL));
+    }
+
+    return (XLookupString(event, buffer_return, buffer_size,
+			  keysym_return, status));
+}
+
 void e_flush_xrect()
 {
  int i;
@@ -433,7 +463,6 @@ int e_x_change(PIC *pic)
  XEvent report;
  XExposeEvent *expose_report;
  KeySym keysym;
- XComposeStatus compose;
  unsigned char buffer[BUFSIZE];
  int charcount;
  unsigned int key_b;
@@ -466,7 +495,7 @@ int e_x_change(PIC *pic)
     }
     break;
    case KeyPress:
-    charcount = XLookupString(&report.xkey, buffer, BUFSIZE, &keysym, &compose);
+    charcount = e_XLookupString(&report.xkey, buffer, BUFSIZE, &keysym, NULL);
     if (charcount == 1 && *buffer == CtrlC) return(CtrlC);
     break;
    case ButtonPress:
@@ -496,7 +525,6 @@ int e_x_getch()
  XEvent report;
  XSelectionEvent se;
  KeySym keysym;
- XComposeStatus compose;
  int charcount;
  unsigned char buffer[BUFSIZE];
  int c, root_x, root_y, x, y;
@@ -559,8 +587,8 @@ int e_x_getch()
     }
     break;
    case KeyPress:
-    charcount = XLookupString(&report.xkey, buffer, BUFSIZE, &keysym,
-      &compose);
+    charcount = e_XLookupString(&report.xkey, buffer, BUFSIZE, &keysym,
+      NULL);
     key_b = report.xkey.state;
     if (charcount == 1)
     {
@@ -718,7 +746,6 @@ int e_x_kbhit()
 {
  XEvent report;
  KeySym keysym;
- XComposeStatus compose;
  int charcount;
  unsigned char buffer[BUFSIZE];
  int c;
@@ -743,8 +770,8 @@ int e_x_kbhit()
  }
  else
  {
-  charcount = XLookupString(&report.xkey, buffer, BUFSIZE,
-						&keysym, &compose);
+  charcount = e_XLookupString(&report.xkey, buffer, BUFSIZE,
+						&keysym, NULL);
   if(charcount == 1) return(*buffer);
   else return(0);
  }
